UPDATE `command` SET `help` = 'Syntax: .levelup #numberoflevels\r\n\r\nIncrease/decrease the level of the selected character by #numberoflevels. If #numberoflevels is omitted, the level will be increase by 1. If #numberoflevels is 0, the same level will be restarted. If no character is selected, increase your level. All stats and dependent values recalculated. At level decrease talents can be reset if need. Also at level decrease equipped items with greater level requirement can be lost.' WHERE `name` = 'levelup';
UPDATE `command` SET `help` = 'Syntax:\r\n.reset level\r\n  Reset level to 1 including reset stats and talents.  Equipped items with greater level requirement can be lost.\r\n.reset spells\r\n  Removes all non-original spells from spellbook.\r\n.reset stats\r\n  Resets(recalculate) all stats of the targeted player to their original values at current level.\r\n.reset talents\r\n  Removes all talents of the targeted player.' WHERE `name` = 'reset';
