delete from command where `name` = 'shuttdown';
delete from command where `name` = 'cshuttdown';
delete from command where `name` = 'shutdown';
delete from command where `name` = 'cshutdown';
insert into command values('shutdown','3','Syntax: .shutdown seconds');
insert into command values('cshutdown','3','Syntax: .cshutdown Cancels shuttdown');

UPDATE `command` SET `help` = 'Syntax: .goobject #object_guid\r\nTeleport your character to gameobject with guid #object_guid' WHERE `name` = 'goobject';
UPDATE `command` SET `help` = 'Syntax: .targetobject [#go_id|#go_name_part]\r\nLocate and show position nearest gameobject. If #go_id or #go_name_part provide then locate and show position of nearest gameobject with gameobject template id #go_id or name included #go_name_part as part.' WHERE `name` = 'targetobject';
UPDATE `command` SET `help` = 'Syntax: .learn #parameter\r\n\r\nSelected character learn a spell of id #parameter. A GM can use .learn all if he wants to learn all default spells for Game Masters, .learn all_lang to learn all languages, and .learn all_myclass to learn all spells available for his class (Character selection in these cases ignored).' WHERE `name` = 'learn';
UPDATE `command` SET `help` = 'Syntax: .taxicheat #flag\r\n\r\nTemporary grant access or remove to all taxi routes for the selected character. If no character is selected, hide or reveal all routes to you.\r\n\r\nUse a #flag of value 1 to add access, use a #flag value of 0 to remove access. Visited taxi nodes sill accessible after removing access.' WHERE `name` = 'taxicheat';
UPDATE `command` SET `help` = 'Syntax: .visible [0||1]\r\n\r\nOutput current visibility state or make GM visible(1) and invisible(0) for other players.' WHERE `name` = 'visible';
UPDATE `command` SET `help` = 'Syntax: .moveobject #goguid [#x #y #z]\r\n\r\nMove gameobject #goguid to character coordinates (or to (#x,#y,#z) coordinates if its provide).' WHERE `name` = 'moveobject';
UPDATE `command` SET `help` = 'Syntax: .playsound #soundid\r\n\r\nPlay sound with #soundid.\r\nSound will be play only for you. Other players do not hear this.\r\nWarning: client may have more 5000 sounds...' WHERE `name` = 'playsound';
UPDATE `command` SET `help` = 'Syntax:\r\n.reset level\r\n  Reset level to 1 including reset stats and talents.  Equipped items with greater level requirement can be lost.\r\n.reset spells\r\n  Removes all non-original spells from spellbook.\r\n.reset stats\r\n  Resets(recalculate) all stats of the targeted player to their original values at current level.\r\n.reset talents\r\n  Removes all talents of the targeted player.' WHERE `name` = 'reset';
UPDATE `command` SET `help` = 'Syntax: .unbanip #ip\r\n\r\nUnban provide IP address.' WHERE `name` = 'unbanip';
UPDATE `command` SET `help` = 'Syntax: .kick [$charactername]\r\n\r\nKick the given character from the world. If no character name provide then selected player (except self) will be kicked.' WHERE `name` = 'kick';
UPDATE `command` SET `help` = 'Syntax: .levelup [$playername] [#numberoflevels]\r\n\r\nIncrease/decrease the level of character with $playername (or the selected if not name provided) by #numberoflevels Or +1 if no #numberoflevels provided). If #numberoflevels is omitted, the level will be increase by 1. If #numberoflevels is 0, the same level will be restarted. If no character is selected and name not provided, increase your level. Command can be used for offline character. All stats and dependent values recalculated. At level decrease talents can be reset if need. Also at level decrease equipped items with greater level requirement can be lost.' WHERE `name` = 'levelup';
UPDATE `command` SET `help` = 'Syntax: .setskill #skill #level [#max]\r\n\r\nSet a skill of id #skill with a current skill value of #level and a maximum value of #max (or equal current maximum if not provide) for the selected character. If no character is selected, you learn the skill.' WHERE `name` = 'setskill';
UPDATE `command` SET `help` = 'Syntax: .learnskill #skillId [#level [#max]]\r\n\r\nLearn a skill of id #skill with a current skill value of #level (or 1 if not provide) and a maximum value of #max (or equal #level or 1 if not provide) for the selected character. If no character is selected, you learn the skill.' WHERE `name` = 'learnskill';
