ALTER TABLE `gameobject_template`
ADD COLUMN `sound10` int(11) unsigned NOT NULL default '0' AFTER `sound9`,
ADD COLUMN `sound11` int(11) unsigned NOT NULL default '0' AFTER `sound10`,
ADD COLUMN `sound12` int(11) unsigned NOT NULL default '0' AFTER `sound11`,
ADD COLUMN `sound13` int(11) unsigned NOT NULL default '0' AFTER `sound12`,
ADD COLUMN `sound14` int(11) unsigned NOT NULL default '0' AFTER `sound13`,
ADD COLUMN `sound15` int(11) unsigned NOT NULL default '0' AFTER `sound14`,
ADD COLUMN `sound16` int(11) unsigned NOT NULL default '0' AFTER `sound15`,
ADD COLUMN `sound17` int(11) unsigned NOT NULL default '0' AFTER `sound16`,
ADD COLUMN `sound18` int(11) unsigned NOT NULL default '0' AFTER `sound17`,
ADD COLUMN `sound19` int(11) unsigned NOT NULL default '0' AFTER `sound18`,
ADD COLUMN `sound20` int(11) unsigned NOT NULL default '0' AFTER `sound19`,
ADD COLUMN `sound21` int(11) unsigned NOT NULL default '0' AFTER `sound20`,
ADD COLUMN `sound22` int(11) unsigned NOT NULL default '0' AFTER `sound21`,
ADD COLUMN `sound23` int(11) unsigned NOT NULL default '0' AFTER `sound22`;
