ALTER TABLE `playercreateinfo_spell` ADD COLUMN `Active` tinyint(3) unsigned NOT NULL default '1';
INSERT INTO `playercreateinfo_spell` VALUES ('21', '3025', 'Cat Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('21', '3122', 'Tree Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('21', '5419', 'Travel Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('21', '5421', 'Aqua Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('21', '1178', 'Bear Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('21', '9635', 'Dire Bear Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('21', '24905', 'Moonkin Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('30', '3025', 'Cat Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('30', '3122', 'Tree Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('30', '5419', 'Travel Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('30', '5421', 'Aqua Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('30', '1178', 'Bear Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('30', '9635', 'Dire Bear Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('30', '24905', 'Moonkin Form Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('1', '7376', 'Defensive Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('1', '7381', 'Berserker Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('7', '7376', 'Defensive Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('7', '7381', 'Berserker Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('12', '7376', 'Defensive Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('12', '7381', 'Berserker Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('17', '7376', 'Defensive Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('17', '7381', 'Berserker Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('22', '7376', 'Defensive Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('22', '7381', 'Berserker Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('27', '7376', 'Defensive Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('27', '7381', 'Berserker Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('31', '7376', 'Defensive Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('31', '7381', 'Berserker Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('35', '7376', 'Defensive Stance Passive', '0');
INSERT INTO `playercreateinfo_spell` VALUES ('35', '7381', 'Berserker Stance Passive', '0');