DROP TABLE IF EXISTS `pet_name_generation`;
CREATE TABLE `pet_name_generation` (
  `id` int(11) NOT NULL auto_increment,
  `word` tinytext NOT NULL,
  `entry` int(11) NOT NULL default '0',
  `half` int(11) NOT NULL default '0',
  PRIMARY KEY  (`id`)
);

/*!40000 ALTER TABLE `pet_name_generation` DISABLE KEYS */;
LOCK TABLES `pet_name_generation` WRITE;
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Aba',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Az',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Bel',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Biz',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Cho',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Dag',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Gak',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Gar',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Gho',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Gob',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Gra',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Jak',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Jub',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Kar',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Laz',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Nal',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Nok',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Pag',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Pig',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Pip',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Piz',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Quz',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Rui',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Rul',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Rup',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Tar',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Vol',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Yaz',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Zep',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Zig',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Zil',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Zor',416,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('bis',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('gup',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('ham',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('jub',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('kin',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('kol',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('lop',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('loz',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('mat',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('mir',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nam',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nar',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nik',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nip',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('pad',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('pep',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('pit',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('qua',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('rai',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('rin',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('rot',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('tai',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('tal',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('tik',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('tip',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('tog',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('tuk',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('uri',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('yal',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('yap',416,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Bar',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Bel',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Char',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Grak\'',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Graz\'',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Grim',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Hath',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Hel',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Hok',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Jhaz',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Jhom',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Kal\'',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Klath',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Krag',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Krak',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Mak',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Mezz',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Orm',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Phan',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Sar',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Tang',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Than',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Thog',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Thok',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Zang',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Zhar\'',1860,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('doc',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('dok',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('garth',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('gore',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('gorg',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('grave',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('gron',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('juk',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('kath',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('kresh',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('krit',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('los',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('mon',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('mos',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('moth',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nagma',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nak',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nar',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nos',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nuz',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('phog',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('rath',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('tast',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('taz',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('thak',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('thang',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('thyk',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('vhug',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('zazt',1860,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Ael',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Aez',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Ang',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Ban',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Bet',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Bro',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Bry',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Dir',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Dom',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Drus',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Fier',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Hel',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Kal',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Lyn',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Mir',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Nim',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Sar',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Sel',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Vil',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Zah',1863,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('aith',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('anda',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('antia',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('lissa',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('neri',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('neth',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nia',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nva',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('ola',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('ona',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('ora',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('riana',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('riel',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('tai',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('vina',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('wena',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('wyn',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('yla',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('yssa',1863,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Flaa',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Fzuu',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Ghaa',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Gree',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Haa',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Jhaa',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Jhuu',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Khaa',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Khii',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Khuu',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Kree',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Maa',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Nhee',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Phuu',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Pryy',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Sloo',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Sruu',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Traa',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('Zhaa',417,0);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('dhon',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('dhum',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('don',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('dym',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('fun',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('ghon',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('ghun',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('grom',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('grym',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('jhom',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('kun',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('mmon',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('mon',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nam',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nem',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nhym',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('nom',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('phom',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('roon',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('tom',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('zhem',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('zhum',417,1);
INSERT INTO `pet_name_generation` (`word`, `entry`, `half`) VALUES ('zun',417,1); 
UNLOCK TABLES;
/*!40000 ALTER TABLE `pet_name_generation` ENABLE KEYS */;
