-- phpMyAdmin SQL Dump
-- version 2.7.0-pl2
-- http://www.phpmyadmin.net
-- 
-- Host: localhost
-- Generation Time: Sep 04, 2006 at 05:27 AM
-- Server version: 5.0.22
-- PHP Version: 5.2.0-dev
-- 
-- Database: `mangos`
-- 

-- --------------------------------------------------------

-- 
-- Table structure for table `player_levelupgains`
-- 

CREATE TABLE `player_levelupgains` (
  `entry` smallint(5) unsigned NOT NULL auto_increment,
  `race` tinyint(3) unsigned NOT NULL,
  `class` tinyint(3) unsigned NOT NULL,
  `level` tinyint(3) unsigned NOT NULL,
  `hp` smallint(5) unsigned NOT NULL,
  `mana` smallint(5) unsigned NOT NULL,
  `str` smallint(5) unsigned NOT NULL,
  `agi` smallint(5) unsigned NOT NULL,
  `sta` smallint(5) unsigned NOT NULL,
  `int` smallint(5) unsigned NOT NULL,
  `spi` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`entry`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 PACK_KEYS=0 COMMENT='Stores level up stat gains.' AUTO_INCREMENT=2401 ;

-- 
-- Dumping data for table `player_levelupgains`
-- 

INSERT INTO `player_levelupgains` VALUES (2, 3, 3, 1, 17, 6, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (3, 3, 3, 2, 17, 21, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (4, 3, 3, 3, 17, 22, 0, 2, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (5, 3, 3, 4, 17, 23, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (6, 3, 3, 5, 17, 24, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (7, 3, 3, 6, 17, 25, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (8, 3, 3, 7, 17, 26, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (9, 3, 3, 8, 17, 27, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (10, 3, 3, 9, 17, 28, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (11, 3, 3, 10, 17, 29, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (12, 3, 3, 11, 17, 30, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (13, 3, 3, 12, 17, 31, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (14, 3, 3, 13, 18, 32, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (15, 3, 3, 14, 19, 33, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (16, 3, 3, 15, 20, 34, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (17, 3, 3, 16, 21, 35, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (18, 3, 3, 17, 22, 36, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (19, 3, 3, 18, 23, 37, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (20, 3, 3, 19, 24, 38, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (21, 3, 3, 20, 25, 39, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (22, 3, 3, 21, 26, 40, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (23, 3, 3, 22, 27, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (24, 3, 3, 23, 28, 42, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (25, 3, 3, 24, 29, 43, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (26, 3, 3, 25, 30, 44, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (27, 3, 3, 26, 31, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (28, 3, 3, 27, 32, 45, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (29, 3, 3, 28, 33, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (30, 3, 3, 29, 34, 45, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (31, 3, 3, 30, 35, 45, 0, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (32, 3, 3, 31, 36, 45, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (33, 3, 3, 32, 37, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (34, 3, 3, 33, 38, 45, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (35, 3, 3, 34, 39, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (36, 3, 3, 35, 40, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (37, 3, 3, 36, 41, 45, 0, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (38, 3, 3, 37, 42, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (39, 3, 3, 38, 43, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (40, 3, 3, 39, 44, 45, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (41, 3, 3, 40, 45, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (42, 3, 3, 41, 46, 45, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (43, 3, 3, 42, 47, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (44, 3, 3, 43, 48, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (45, 3, 3, 44, 49, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (46, 3, 3, 45, 50, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (47, 3, 3, 46, 51, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (48, 3, 3, 47, 52, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (49, 3, 3, 48, 53, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (50, 3, 3, 49, 54, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (51, 3, 3, 50, 55, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (52, 3, 3, 51, 56, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (53, 3, 3, 52, 57, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (54, 3, 3, 53, 58, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (55, 3, 3, 54, 59, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (56, 3, 3, 55, 60, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (57, 3, 3, 56, 61, 45, 1, 3, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (58, 3, 3, 57, 62, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (59, 3, 3, 58, 63, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (60, 3, 3, 59, 64, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (62, 3, 2, 1, 18, 5, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (63, 3, 2, 2, 18, 20, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (64, 3, 2, 3, 18, 21, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (65, 3, 2, 4, 18, 22, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (66, 3, 2, 5, 18, 23, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (67, 3, 2, 6, 18, 24, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (68, 3, 2, 7, 18, 25, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (69, 3, 2, 8, 18, 26, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (70, 3, 2, 9, 18, 27, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (71, 3, 2, 10, 18, 28, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (72, 3, 2, 11, 18, 29, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (73, 3, 2, 12, 18, 30, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (74, 3, 2, 13, 18, 31, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (75, 3, 2, 14, 19, 32, 1, 1, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (76, 3, 2, 15, 20, 33, 2, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (77, 3, 2, 16, 21, 34, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (78, 3, 2, 17, 22, 35, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (79, 3, 2, 18, 23, 36, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (80, 3, 2, 19, 24, 37, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (81, 3, 2, 20, 25, 38, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (82, 3, 2, 21, 26, 39, 2, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (83, 3, 2, 22, 27, 40, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (84, 3, 2, 23, 28, 41, 1, 1, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (85, 3, 2, 24, 29, 42, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (86, 3, 2, 25, 30, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (87, 3, 2, 26, 31, 42, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (88, 3, 2, 27, 32, 42, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (89, 3, 2, 28, 33, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (90, 3, 2, 29, 34, 42, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (91, 3, 2, 30, 35, 42, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (92, 3, 2, 31, 36, 42, 2, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (93, 3, 2, 32, 37, 42, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (94, 3, 2, 33, 38, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (95, 3, 2, 34, 39, 42, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (96, 3, 2, 35, 40, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (97, 3, 2, 36, 41, 42, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (98, 3, 2, 37, 42, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (99, 3, 2, 38, 43, 42, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (100, 3, 2, 39, 44, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (101, 3, 2, 40, 45, 42, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (102, 3, 2, 41, 46, 42, 2, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (103, 3, 2, 42, 47, 42, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (104, 3, 2, 43, 48, 42, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (105, 3, 2, 44, 49, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (106, 3, 2, 45, 50, 42, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (107, 3, 2, 46, 51, 42, 2, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (108, 3, 2, 47, 52, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (109, 3, 2, 48, 53, 42, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (110, 3, 2, 49, 54, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (111, 3, 2, 50, 55, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (112, 3, 2, 51, 56, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (113, 3, 2, 52, 57, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (114, 3, 2, 53, 58, 42, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (115, 3, 2, 54, 59, 42, 2, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (116, 3, 2, 55, 60, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (117, 3, 2, 56, 61, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (118, 3, 2, 57, 62, 42, 2, 1, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (119, 3, 2, 58, 63, 42, 2, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (120, 3, 2, 59, 64, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (122, 3, 5, 1, 15, 24, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (123, 3, 5, 2, 15, 25, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (124, 3, 5, 3, 15, 26, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (125, 3, 5, 4, 15, 27, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (126, 3, 5, 5, 15, 28, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (127, 3, 5, 6, 15, 29, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (128, 3, 5, 7, 15, 30, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (129, 3, 5, 8, 15, 31, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (130, 3, 5, 9, 15, 47, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (131, 3, 5, 10, 15, 18, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (132, 3, 5, 11, 15, 34, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (133, 3, 5, 12, 15, 35, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (134, 3, 5, 13, 15, 36, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (135, 3, 5, 14, 15, 37, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (136, 3, 5, 15, 15, 38, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (137, 3, 5, 16, 15, 54, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (138, 3, 5, 17, 15, 25, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (139, 3, 5, 18, 15, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (140, 3, 5, 19, 15, 42, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (141, 3, 5, 20, 15, 43, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (142, 3, 5, 21, 16, 59, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (143, 3, 5, 22, 17, 30, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (144, 3, 5, 23, 18, 61, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (145, 3, 5, 24, 19, 32, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (146, 3, 5, 25, 20, 63, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (147, 3, 5, 26, 21, 34, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (148, 3, 5, 27, 22, 65, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (149, 3, 5, 28, 23, 36, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (150, 3, 5, 29, 24, 52, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (151, 3, 5, 30, 25, 68, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (152, 3, 5, 31, 26, 39, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (153, 3, 5, 32, 27, 69, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (154, 3, 5, 33, 28, 54, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (155, 3, 5, 34, 29, 39, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (156, 3, 5, 35, 30, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (157, 3, 5, 36, 31, 69, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (158, 3, 5, 37, 32, 54, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (159, 3, 5, 38, 33, 39, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (160, 3, 5, 39, 34, 54, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (161, 3, 5, 40, 35, 69, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (162, 3, 5, 41, 36, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (163, 3, 5, 42, 37, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (164, 3, 5, 43, 38, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (165, 3, 5, 44, 39, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (166, 3, 5, 45, 40, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (167, 3, 5, 46, 41, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (168, 3, 5, 47, 42, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (169, 3, 5, 48, 43, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (170, 3, 5, 49, 44, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (171, 3, 5, 50, 45, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (172, 3, 5, 51, 46, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (173, 3, 5, 52, 47, 54, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (174, 3, 5, 53, 48, 54, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (175, 3, 5, 54, 49, 54, 0, 1, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (176, 3, 5, 55, 50, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (177, 3, 5, 56, 51, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (178, 3, 5, 57, 52, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (179, 3, 5, 58, 53, 54, 1, 1, 0, 3, 3);
INSERT INTO `player_levelupgains` VALUES (180, 3, 5, 59, 54, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (182, 3, 4, 1, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (183, 3, 4, 2, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (184, 3, 4, 3, 17, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (185, 3, 4, 4, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (186, 3, 4, 5, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (187, 3, 4, 6, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (188, 3, 4, 7, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (189, 3, 4, 8, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (190, 3, 4, 9, 17, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (191, 3, 4, 10, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (192, 3, 4, 11, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (193, 3, 4, 12, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (194, 3, 4, 13, 17, 0, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (195, 3, 4, 14, 17, 0, 1, 2, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (196, 3, 4, 15, 18, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (197, 3, 4, 16, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (198, 3, 4, 17, 20, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (199, 3, 4, 18, 21, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (200, 3, 4, 19, 22, 0, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (201, 3, 4, 20, 23, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (202, 3, 4, 21, 24, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (203, 3, 4, 22, 25, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (204, 3, 4, 23, 26, 0, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (205, 3, 4, 24, 27, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (206, 3, 4, 25, 28, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (207, 3, 4, 26, 29, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (208, 3, 4, 27, 30, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (209, 3, 4, 28, 31, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (210, 3, 4, 29, 32, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (211, 3, 4, 30, 33, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (212, 3, 4, 31, 34, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (213, 3, 4, 32, 35, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (214, 3, 4, 33, 36, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (215, 3, 4, 34, 37, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (216, 3, 4, 35, 38, 0, 2, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (217, 3, 4, 36, 39, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (218, 3, 4, 37, 40, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (219, 3, 4, 38, 41, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (220, 3, 4, 39, 42, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (221, 3, 4, 40, 43, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (222, 3, 4, 41, 44, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (223, 3, 4, 42, 45, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (224, 3, 4, 43, 46, 0, 1, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (225, 3, 4, 44, 47, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (226, 3, 4, 45, 48, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (227, 3, 4, 46, 49, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (228, 3, 4, 47, 50, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (229, 3, 4, 48, 51, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (230, 3, 4, 49, 52, 0, 2, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (231, 3, 4, 50, 53, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (232, 3, 4, 51, 54, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (233, 3, 4, 52, 55, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (234, 3, 4, 53, 56, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (235, 3, 4, 54, 57, 0, 1, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (236, 3, 4, 55, 58, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (237, 3, 4, 56, 59, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (238, 3, 4, 57, 60, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (239, 3, 4, 58, 61, 0, 2, 2, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (240, 3, 4, 59, 62, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (242, 3, 1, 1, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (243, 3, 1, 2, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (244, 3, 1, 3, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (245, 3, 1, 4, 19, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (246, 3, 1, 5, 19, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (247, 3, 1, 6, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (248, 3, 1, 7, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (249, 3, 1, 8, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (250, 3, 1, 9, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (251, 3, 1, 10, 19, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (252, 3, 1, 11, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (253, 3, 1, 12, 19, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (254, 3, 1, 13, 20, 0, 2, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (255, 3, 1, 14, 21, 0, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (256, 3, 1, 15, 22, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (257, 3, 1, 16, 23, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (258, 3, 1, 17, 24, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (259, 3, 1, 18, 25, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (260, 3, 1, 19, 26, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (261, 3, 1, 20, 27, 0, 1, 0, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (262, 3, 1, 21, 28, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (263, 3, 1, 22, 29, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (264, 3, 1, 23, 30, 0, 1, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (265, 3, 1, 24, 31, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (266, 3, 1, 25, 32, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (267, 3, 1, 26, 33, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (268, 3, 1, 27, 34, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (269, 3, 1, 28, 35, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (270, 3, 1, 29, 36, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (271, 3, 1, 30, 37, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (272, 3, 1, 31, 38, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (273, 3, 1, 32, 39, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (274, 3, 1, 33, 40, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (275, 3, 1, 34, 41, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (276, 3, 1, 35, 42, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (277, 3, 1, 36, 44, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (278, 3, 1, 37, 46, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (279, 3, 1, 38, 48, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (280, 3, 1, 39, 50, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (281, 3, 1, 40, 52, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (282, 3, 1, 41, 54, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (283, 3, 1, 42, 56, 0, 2, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (284, 3, 1, 43, 58, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (285, 3, 1, 44, 60, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (286, 3, 1, 45, 62, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (287, 3, 1, 46, 64, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (288, 3, 1, 47, 66, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (289, 3, 1, 48, 68, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (290, 3, 1, 49, 70, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (291, 3, 1, 50, 72, 0, 2, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (292, 3, 1, 51, 74, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (293, 3, 1, 52, 76, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (294, 3, 1, 53, 78, 0, 2, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (295, 3, 1, 54, 80, 0, 3, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (296, 3, 1, 55, 82, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (297, 3, 1, 56, 84, 0, 2, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (298, 3, 1, 57, 86, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (299, 3, 1, 58, 88, 0, 3, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (300, 3, 1, 59, 90, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (302, 7, 8, 1, 15, 25, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (303, 7, 8, 2, 6, 26, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (304, 7, 8, 3, 15, 27, 0, 1, 0, 3, 1);
INSERT INTO `player_levelupgains` VALUES (305, 7, 8, 4, 15, 58, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (306, 7, 8, 5, 15, 29, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (307, 7, 8, 6, 15, 30, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (308, 7, 8, 7, 15, 16, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (309, 7, 8, 8, 15, 47, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (310, 7, 8, 9, 15, 33, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (311, 7, 8, 10, 15, 34, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (312, 7, 8, 11, 15, 35, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (313, 7, 8, 12, 15, 21, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (314, 7, 8, 13, 15, 37, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (315, 7, 8, 14, 15, 38, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (316, 7, 8, 15, 15, 39, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (317, 7, 8, 16, 15, 25, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (318, 7, 8, 17, 15, 56, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (319, 7, 8, 18, 15, 27, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (320, 7, 8, 19, 15, 88, 0, 1, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (321, 7, 8, 20, 15, 29, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (322, 7, 8, 21, 15, 60, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (323, 7, 8, 22, 15, 31, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (324, 7, 8, 23, 16, 62, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (325, 7, 8, 24, 17, 33, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (326, 7, 8, 25, 18, 64, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (327, 7, 8, 26, 19, 35, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (328, 7, 8, 27, 20, 36, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (329, 7, 8, 28, 21, 66, 0, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (330, 7, 8, 29, 22, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (331, 7, 8, 30, 23, 36, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (332, 7, 8, 31, 24, 66, 0, 0, 1, 3, 1);
INSERT INTO `player_levelupgains` VALUES (333, 7, 8, 32, 25, 81, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (334, 7, 8, 33, 26, 36, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (335, 7, 8, 34, 27, 51, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (336, 7, 8, 35, 28, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (337, 7, 8, 36, 29, 66, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (338, 7, 8, 37, 30, 36, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (339, 7, 8, 38, 31, 51, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (340, 7, 8, 39, 32, 36, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (341, 7, 8, 40, 33, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (342, 7, 8, 41, 34, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (343, 7, 8, 42, 35, 51, 0, 0, 1, 3, 2);
INSERT INTO `player_levelupgains` VALUES (344, 7, 8, 43, 36, 81, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (345, 7, 8, 44, 37, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (346, 7, 8, 45, 38, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (347, 7, 8, 46, 39, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (348, 7, 8, 47, 40, 51, 0, 0, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (349, 7, 8, 48, 41, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (350, 7, 8, 49, 42, 36, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (351, 7, 8, 50, 43, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (352, 7, 8, 51, 44, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (353, 7, 8, 52, 45, 81, 0, 1, 1, 3, 2);
INSERT INTO `player_levelupgains` VALUES (354, 7, 8, 53, 46, 51, 1, 0, 1, 3, 2);
INSERT INTO `player_levelupgains` VALUES (355, 7, 8, 54, 47, 51, 0, 0, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (356, 7, 8, 55, 48, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (357, 7, 8, 56, 49, 36, 0, 0, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (358, 7, 8, 57, 50, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (359, 7, 8, 58, 51, 51, 0, 1, 0, 3, 3);
INSERT INTO `player_levelupgains` VALUES (360, 7, 8, 59, 52, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (362, 7, 4, 1, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (363, 7, 4, 2, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (364, 7, 4, 3, 17, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (365, 7, 4, 4, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (366, 7, 4, 5, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (367, 7, 4, 6, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (368, 7, 4, 7, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (369, 7, 4, 8, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (370, 7, 4, 9, 17, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (371, 7, 4, 10, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (372, 7, 4, 11, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (373, 7, 4, 12, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (374, 7, 4, 13, 17, 0, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (375, 7, 4, 14, 17, 0, 1, 2, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (376, 7, 4, 15, 18, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (377, 7, 4, 16, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (378, 7, 4, 17, 20, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (379, 7, 4, 18, 21, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (380, 7, 4, 19, 22, 0, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (381, 7, 4, 20, 23, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (382, 7, 4, 21, 24, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (383, 7, 4, 22, 25, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (384, 7, 4, 23, 26, 0, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (385, 7, 4, 24, 27, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (386, 7, 4, 25, 28, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (387, 7, 4, 26, 29, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (388, 7, 4, 27, 30, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (389, 7, 4, 28, 31, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (390, 7, 4, 29, 32, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (391, 7, 4, 30, 33, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (392, 7, 4, 31, 34, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (393, 7, 4, 32, 35, 0, 1, 2, 1, 2, 0);
INSERT INTO `player_levelupgains` VALUES (394, 7, 4, 33, 36, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (395, 7, 4, 34, 37, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (396, 7, 4, 35, 38, 0, 2, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (397, 7, 4, 36, 39, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (398, 7, 4, 37, 40, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (399, 7, 4, 38, 41, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (400, 7, 4, 39, 42, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (401, 7, 4, 40, 43, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (402, 7, 4, 41, 44, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (403, 7, 4, 42, 45, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (404, 7, 4, 43, 46, 0, 1, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (405, 7, 4, 44, 47, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (406, 7, 4, 45, 48, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (407, 7, 4, 46, 49, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (408, 7, 4, 47, 50, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (409, 7, 4, 48, 51, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (410, 7, 4, 49, 52, 0, 2, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (411, 7, 4, 50, 53, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (412, 7, 4, 51, 54, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (413, 7, 4, 52, 55, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (414, 7, 4, 53, 56, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (415, 7, 4, 54, 57, 0, 1, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (416, 7, 4, 55, 58, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (417, 7, 4, 56, 59, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (418, 7, 4, 57, 60, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (419, 7, 4, 58, 61, 0, 2, 2, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (420, 7, 4, 59, 62, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (422, 7, 9, 1, 15, 23, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (423, 7, 9, 2, 15, 24, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (424, 7, 9, 3, 15, 25, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (425, 7, 9, 4, 15, 26, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (426, 7, 9, 5, 15, 27, 0, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (427, 7, 9, 6, 15, 58, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (428, 7, 9, 7, 15, 29, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (429, 7, 9, 8, 15, 30, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (430, 7, 9, 9, 15, 31, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (431, 7, 9, 10, 15, 32, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (432, 7, 9, 11, 15, 33, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (433, 7, 9, 12, 15, 34, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (434, 7, 9, 13, 15, 35, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (435, 7, 9, 14, 15, 36, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (436, 7, 9, 15, 15, 22, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (437, 7, 9, 16, 15, 38, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (438, 7, 9, 17, 16, 39, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (439, 7, 9, 18, 17, 40, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (440, 7, 9, 19, 18, 41, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (441, 7, 9, 20, 19, 42, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (442, 7, 9, 21, 20, 43, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (443, 7, 9, 22, 21, 44, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (444, 7, 9, 23, 22, 75, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (445, 7, 9, 24, 23, 46, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (446, 7, 9, 25, 24, 47, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (447, 7, 9, 26, 25, 48, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (448, 7, 9, 27, 26, 49, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (449, 7, 9, 28, 27, 50, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (450, 7, 9, 29, 28, 51, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (451, 7, 9, 30, 19, 36, 0, 0, 0, 1, 3);
INSERT INTO `player_levelupgains` VALUES (452, 7, 9, 31, 40, 51, 1, 1, 2, 2, 0);
INSERT INTO `player_levelupgains` VALUES (453, 7, 9, 32, 31, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (454, 7, 9, 33, 32, 51, 1, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (455, 7, 9, 34, 33, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (456, 7, 9, 35, 34, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (457, 7, 9, 36, 35, 81, 0, 1, 1, 3, 0);
INSERT INTO `player_levelupgains` VALUES (458, 7, 9, 37, 36, 51, 0, 0, 1, 1, 3);
INSERT INTO `player_levelupgains` VALUES (459, 7, 9, 38, 37, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (460, 7, 9, 39, 38, 51, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (461, 7, 9, 40, 39, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (462, 7, 9, 41, 40, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (463, 7, 9, 42, 41, 51, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (464, 7, 9, 43, 42, 36, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (465, 7, 9, 44, 43, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (466, 7, 9, 45, 44, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (467, 7, 9, 46, 45, 51, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (468, 7, 9, 47, 36, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (469, 7, 9, 48, 47, 81, 1, 1, 1, 3, 2);
INSERT INTO `player_levelupgains` VALUES (470, 7, 9, 49, 58, 51, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (471, 7, 9, 50, 49, 51, 1, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (472, 7, 9, 51, 30, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (473, 7, 9, 52, 71, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (474, 7, 9, 53, 52, 36, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (475, 7, 9, 54, 43, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (476, 7, 9, 55, 64, 51, 1, 1, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (477, 7, 9, 56, 35, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (478, 7, 9, 57, 76, 51, 1, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (479, 7, 9, 58, 57, 81, 0, 0, 1, 3, 0);
INSERT INTO `player_levelupgains` VALUES (480, 7, 9, 59, 58, 51, 1, 1, 1, 2, 4);
INSERT INTO `player_levelupgains` VALUES (482, 7, 1, 1, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (483, 7, 1, 2, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (484, 7, 1, 3, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (485, 7, 1, 4, 19, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (486, 7, 1, 5, 19, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (487, 7, 1, 6, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (488, 7, 1, 7, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (489, 7, 1, 8, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (490, 7, 1, 9, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (491, 7, 1, 10, 19, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (492, 7, 1, 11, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (493, 7, 1, 12, 19, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (494, 7, 1, 13, 20, 0, 2, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (495, 7, 1, 14, 21, 0, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (496, 7, 1, 15, 22, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (497, 7, 1, 16, 23, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (498, 7, 1, 17, 24, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (499, 7, 1, 18, 25, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (500, 7, 1, 19, 26, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (501, 7, 1, 20, 27, 0, 1, 0, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (502, 7, 1, 21, 28, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (503, 7, 1, 22, 29, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (504, 7, 1, 23, 30, 0, 1, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (505, 7, 1, 24, 31, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (506, 7, 1, 25, 32, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (507, 7, 1, 26, 33, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (508, 7, 1, 27, 34, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (509, 7, 1, 28, 35, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (510, 7, 1, 29, 36, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (511, 7, 1, 30, 37, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (512, 7, 1, 31, 38, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (513, 7, 1, 32, 39, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (514, 7, 1, 33, 40, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (515, 7, 1, 34, 41, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (516, 7, 1, 35, 42, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (517, 7, 1, 36, 79, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (518, 7, 1, 37, 11, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (519, 7, 1, 38, 48, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (520, 7, 1, 39, 50, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (521, 7, 1, 40, 52, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (522, 7, 1, 41, 54, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (523, 7, 1, 42, 56, 0, 2, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (524, 7, 1, 43, 58, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (525, 7, 1, 44, 60, 0, 2, 1, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (526, 7, 1, 45, 62, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (527, 7, 1, 46, 64, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (528, 7, 1, 47, 66, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (529, 7, 1, 48, 68, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (530, 7, 1, 49, 70, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (531, 7, 1, 50, 72, 0, 2, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (532, 7, 1, 51, 74, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (533, 7, 1, 52, 76, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (534, 7, 1, 53, 78, 0, 2, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (535, 7, 1, 54, 80, 0, 3, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (536, 7, 1, 55, 82, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (537, 7, 1, 56, 84, 0, 2, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (538, 7, 1, 57, 86, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (539, 7, 1, 58, 88, 0, 3, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (540, 7, 1, 59, 90, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (542, 1, 8, 1, 15, 25, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (543, 1, 8, 2, 15, 26, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (544, 1, 8, 3, 15, 27, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (545, 1, 8, 4, 15, 28, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (546, 1, 8, 5, 15, 29, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (547, 1, 8, 6, 15, 30, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (548, 1, 8, 7, 15, 16, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (549, 1, 8, 8, 15, 47, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (550, 1, 8, 9, 15, 33, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (551, 1, 8, 10, 15, 34, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (552, 1, 8, 11, 15, 35, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (553, 1, 8, 12, 15, 36, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (554, 1, 8, 13, 15, 37, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (555, 1, 8, 14, 15, 38, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (556, 1, 8, 15, 15, 39, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (557, 1, 8, 16, 15, 25, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (558, 1, 8, 17, 15, 56, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (559, 1, 8, 18, 15, 27, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (560, 1, 8, 19, 15, 58, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (561, 1, 8, 20, 15, 29, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (562, 1, 8, 21, 15, 60, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (563, 1, 8, 22, 15, 31, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (564, 1, 8, 23, 16, 62, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (565, 1, 8, 24, 17, 33, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (566, 1, 8, 25, 18, 64, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (567, 1, 8, 26, 19, 50, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (568, 1, 8, 27, 20, 36, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (569, 1, 8, 28, 21, 66, 0, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (570, 1, 8, 29, 22, 51, 0, 0, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (571, 1, 8, 30, 23, 36, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (572, 1, 8, 31, 24, 66, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (573, 1, 8, 32, 25, 51, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (574, 1, 8, 33, 26, 36, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (575, 1, 8, 34, 27, 51, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (576, 1, 8, 35, 28, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (577, 1, 8, 36, 29, 66, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (578, 1, 8, 37, 30, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (579, 1, 8, 38, 31, 51, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (580, 1, 8, 39, 32, 36, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (581, 1, 8, 40, 33, 51, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (582, 1, 8, 41, 34, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (583, 1, 8, 42, 35, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (584, 1, 8, 43, 36, 51, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (585, 1, 8, 44, 37, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (586, 1, 8, 45, 38, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (587, 1, 8, 46, 39, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (588, 1, 8, 47, 40, 66, 0, 0, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (589, 1, 8, 48, 41, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (590, 1, 8, 49, 42, 36, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (591, 1, 8, 50, 43, 51, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (592, 1, 8, 51, 44, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (593, 1, 8, 52, 45, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (594, 1, 8, 53, 46, 51, 1, 0, 1, 3, 2);
INSERT INTO `player_levelupgains` VALUES (595, 1, 8, 54, 47, 51, 0, 0, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (596, 1, 8, 55, 48, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (597, 1, 8, 56, 49, 51, 0, 0, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (598, 1, 8, 57, 50, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (599, 1, 8, 58, 51, 51, 0, 1, 0, 3, 3);
INSERT INTO `player_levelupgains` VALUES (600, 1, 8, 59, 52, 51, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (602, 1, 2, 1, 18, 19, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (603, 1, 2, 2, 18, 20, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (604, 1, 2, 3, 18, 21, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (605, 1, 2, 4, 18, 22, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (606, 1, 2, 5, 18, 23, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (607, 1, 2, 6, 18, 24, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (608, 1, 2, 7, 18, 25, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (609, 1, 2, 8, 18, 26, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (610, 1, 2, 9, 18, 27, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (611, 1, 2, 10, 18, 28, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (612, 1, 2, 11, 18, 29, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (613, 1, 2, 12, 18, 30, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (614, 1, 2, 13, 18, 31, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (615, 1, 2, 14, 19, 32, 1, 1, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (616, 1, 2, 15, 20, 33, 2, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (617, 1, 2, 16, 21, 34, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (618, 1, 2, 17, 22, 35, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (619, 1, 2, 18, 23, 36, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (620, 1, 2, 19, 24, 37, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (621, 1, 2, 20, 25, 38, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (622, 1, 2, 21, 26, 39, 2, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (623, 1, 2, 22, 27, 40, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (624, 1, 2, 23, 28, 41, 1, 1, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (625, 1, 2, 24, 29, 42, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (626, 1, 2, 25, 30, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (627, 1, 2, 26, 31, 42, 1, 1, 1, 0, 2);
INSERT INTO `player_levelupgains` VALUES (628, 1, 2, 27, 32, 42, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (629, 1, 2, 28, 33, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (630, 1, 2, 29, 34, 42, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (631, 1, 2, 30, 35, 42, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (632, 1, 2, 31, 36, 42, 2, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (633, 1, 2, 32, 37, 42, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (634, 1, 2, 33, 38, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (635, 1, 2, 34, 39, 42, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (636, 1, 2, 35, 40, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (637, 1, 2, 36, 41, 42, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (638, 1, 2, 37, 42, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (639, 1, 2, 38, 43, 42, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (640, 1, 2, 39, 44, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (641, 1, 2, 40, 45, 42, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (642, 1, 2, 41, 46, 42, 2, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (643, 1, 2, 42, 47, 42, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (644, 1, 2, 43, 48, 42, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (645, 1, 2, 44, 49, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (646, 1, 2, 45, 50, 42, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (647, 1, 2, 46, 51, 42, 2, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (648, 1, 2, 47, 52, 42, 2, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (649, 1, 2, 48, 53, 42, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (650, 1, 2, 49, 54, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (651, 1, 2, 50, 55, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (652, 1, 2, 51, 56, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (653, 1, 2, 52, 57, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (654, 1, 2, 53, 58, 42, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (655, 1, 2, 54, 59, 42, 2, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (656, 1, 2, 55, 60, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (657, 1, 2, 56, 61, 42, 2, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (658, 1, 2, 57, 62, 42, 2, 1, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (659, 1, 2, 58, 63, 42, 2, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (660, 1, 2, 59, 64, 42, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (662, 1, 5, 1, 15, 24, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (663, 1, 5, 2, 15, 25, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (664, 1, 5, 3, 15, 26, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (665, 1, 5, 4, 15, 27, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (666, 1, 5, 5, 15, 28, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (667, 1, 5, 6, 15, 29, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (668, 1, 5, 7, 15, 30, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (669, 1, 5, 8, 15, 31, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (670, 1, 5, 9, 15, 47, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (671, 1, 5, 10, 15, 18, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (672, 1, 5, 11, 15, 34, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (673, 1, 5, 12, 15, 35, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (674, 1, 5, 13, 15, 36, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (675, 1, 5, 14, 15, 37, 1, 0, 0, 1, 3);
INSERT INTO `player_levelupgains` VALUES (676, 1, 5, 15, 15, 38, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (677, 1, 5, 16, 15, 54, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (678, 1, 5, 17, 15, 25, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (679, 1, 5, 18, 15, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (680, 1, 5, 19, 15, 42, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (681, 1, 5, 20, 15, 43, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (682, 1, 5, 21, 16, 59, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (683, 1, 5, 22, 17, 30, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (684, 1, 5, 23, 18, 61, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (685, 1, 5, 24, 19, 32, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (686, 1, 5, 25, 20, 63, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (687, 1, 5, 26, 21, 34, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (688, 1, 5, 27, 22, 65, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (689, 1, 5, 28, 23, 36, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (690, 1, 5, 29, 24, 52, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (691, 1, 5, 30, 25, 68, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (692, 1, 5, 31, 26, 39, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (693, 1, 5, 32, 27, 69, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (694, 1, 5, 33, 28, 54, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (695, 1, 5, 34, 29, 39, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (696, 1, 5, 35, 30, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (697, 1, 5, 36, 31, 69, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (698, 1, 5, 37, 32, 54, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (699, 1, 5, 38, 33, 39, 0, 0, 1, 1, 3);
INSERT INTO `player_levelupgains` VALUES (700, 1, 5, 39, 34, 54, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (701, 1, 5, 40, 35, 69, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (702, 1, 5, 41, 36, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (703, 1, 5, 42, 37, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (704, 1, 5, 43, 38, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (705, 1, 5, 44, 39, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (706, 1, 5, 45, 40, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (707, 1, 5, 46, 41, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (708, 1, 5, 47, 42, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (709, 1, 5, 48, 43, 54, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (710, 1, 5, 49, 44, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (711, 1, 5, 50, 45, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (712, 1, 5, 51, 46, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (713, 1, 5, 52, 47, 54, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (714, 1, 5, 53, 48, 54, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (715, 1, 5, 54, 49, 54, 0, 1, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (716, 1, 5, 55, 50, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (717, 1, 5, 56, 51, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (718, 1, 5, 57, 52, 54, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (719, 1, 5, 58, 53, 54, 1, 1, 0, 3, 3);
INSERT INTO `player_levelupgains` VALUES (720, 1, 5, 59, 54, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (722, 1, 4, 1, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (723, 1, 4, 2, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (724, 1, 4, 3, 17, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (725, 1, 4, 4, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (726, 1, 4, 5, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (727, 1, 4, 6, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (728, 1, 4, 7, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (729, 1, 4, 8, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (730, 1, 4, 9, 17, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (731, 1, 4, 10, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (732, 1, 4, 11, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (733, 1, 4, 12, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (734, 1, 4, 13, 17, 0, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (735, 1, 4, 14, 17, 0, 1, 2, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (736, 1, 4, 15, 18, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (737, 1, 4, 16, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (738, 1, 4, 17, 20, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (739, 1, 4, 18, 21, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (740, 1, 4, 19, 22, 0, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (741, 1, 4, 20, 23, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (742, 1, 4, 21, 24, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (743, 1, 4, 22, 25, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (744, 1, 4, 23, 26, 0, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (745, 1, 4, 24, 27, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (746, 1, 4, 25, 28, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (747, 1, 4, 26, 29, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (748, 1, 4, 27, 30, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (749, 1, 4, 28, 31, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (750, 1, 4, 29, 32, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (751, 1, 4, 30, 33, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (752, 1, 4, 31, 34, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (753, 1, 4, 32, 35, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (754, 1, 4, 33, 36, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (755, 1, 4, 34, 37, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (756, 1, 4, 35, 38, 0, 2, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (757, 1, 4, 36, 39, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (758, 1, 4, 37, 40, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (759, 1, 4, 38, 41, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (760, 1, 4, 39, 42, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (761, 1, 4, 40, 43, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (762, 1, 4, 41, 44, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (763, 1, 4, 42, 45, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (764, 1, 4, 43, 46, 0, 1, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (765, 1, 4, 44, 47, 0, 2, 2, 1, 0, 2);
INSERT INTO `player_levelupgains` VALUES (766, 1, 4, 45, 48, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (767, 1, 4, 46, 49, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (768, 1, 4, 47, 50, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (769, 1, 4, 48, 51, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (770, 1, 4, 49, 52, 0, 2, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (771, 1, 4, 50, 53, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (772, 1, 4, 51, 54, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (773, 1, 4, 52, 55, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (774, 1, 4, 53, 56, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (775, 1, 4, 54, 57, 0, 1, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (776, 1, 4, 55, 58, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (777, 1, 4, 56, 59, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (778, 1, 4, 57, 60, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (779, 1, 4, 58, 61, 0, 2, 2, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (780, 1, 4, 59, 62, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (782, 1, 9, 1, 15, 23, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (783, 1, 9, 2, 15, 24, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (784, 1, 9, 3, 15, 25, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (785, 1, 9, 4, 15, 26, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (786, 1, 9, 5, 15, 27, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (787, 1, 9, 6, 15, 28, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (788, 1, 9, 7, 15, 29, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (789, 1, 9, 8, 15, 30, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (790, 1, 9, 9, 15, 31, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (791, 1, 9, 10, 15, 32, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (792, 1, 9, 11, 15, 33, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (793, 1, 9, 12, 15, 34, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (794, 1, 9, 13, 15, 35, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (795, 1, 9, 14, 15, 36, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (796, 1, 9, 15, 15, 37, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (797, 1, 9, 16, 15, 38, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (798, 1, 9, 17, 16, 39, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (799, 1, 9, 18, 17, 40, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (800, 1, 9, 19, 18, 41, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (801, 1, 9, 20, 19, 42, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (802, 1, 9, 21, 20, 43, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (803, 1, 9, 22, 21, 44, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (804, 1, 9, 23, 22, 45, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (805, 1, 9, 24, 23, 46, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (806, 1, 9, 25, 24, 47, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (807, 1, 9, 26, 25, 48, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (808, 1, 9, 27, 26, 49, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (809, 1, 9, 28, 27, 50, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (810, 1, 9, 29, 28, 51, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (811, 1, 9, 30, 29, 51, 0, 0, 1, 1, 3);
INSERT INTO `player_levelupgains` VALUES (812, 1, 9, 31, 30, 51, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (813, 1, 9, 32, 31, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (814, 1, 9, 33, 32, 51, 1, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (815, 1, 9, 34, 33, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (816, 1, 9, 35, 34, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (817, 1, 9, 36, 35, 51, 0, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (818, 1, 9, 37, 36, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (819, 1, 9, 38, 37, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (820, 1, 9, 39, 38, 51, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (821, 1, 9, 40, 39, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (822, 1, 9, 41, 40, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (823, 1, 9, 42, 31, 51, 1, 1, 0, 1, 4);
INSERT INTO `player_levelupgains` VALUES (824, 1, 9, 43, 52, 51, 0, 0, 2, 2, 0);
INSERT INTO `player_levelupgains` VALUES (825, 1, 9, 44, 43, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (826, 1, 9, 45, 34, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (827, 1, 9, 46, 55, 51, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (828, 1, 9, 47, 46, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (829, 1, 9, 48, 47, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (830, 1, 9, 49, 48, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (831, 1, 9, 50, 49, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (832, 1, 9, 51, 50, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (833, 1, 9, 52, 41, 51, 1, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (834, 1, 9, 53, 52, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (835, 1, 9, 54, 63, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (836, 1, 9, 55, 54, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (837, 1, 9, 56, 55, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (838, 1, 9, 57, 56, 51, 1, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (839, 1, 9, 58, 57, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (840, 1, 9, 59, 58, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (842, 1, 1, 1, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (843, 1, 1, 2, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (844, 1, 1, 3, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (845, 1, 1, 4, 19, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (846, 1, 1, 5, 19, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (847, 1, 1, 6, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (848, 1, 1, 7, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (849, 1, 1, 8, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (850, 1, 1, 9, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (851, 1, 1, 10, 19, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (852, 1, 1, 11, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (853, 1, 1, 12, 19, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (854, 1, 1, 13, 20, 0, 2, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (855, 1, 1, 14, 21, 0, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (856, 1, 1, 15, 22, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (857, 1, 1, 16, 23, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (858, 1, 1, 17, 24, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (859, 1, 1, 18, 0, 0, 0, 0, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (860, 1, 1, 19, 51, 0, 3, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (861, 1, 1, 20, 27, 0, 1, 0, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (862, 1, 1, 21, 28, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (863, 1, 1, 22, 29, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (864, 1, 1, 23, 30, 0, 1, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (865, 1, 1, 24, 31, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (866, 1, 1, 25, 32, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (867, 1, 1, 26, 33, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (868, 1, 1, 27, 34, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (869, 1, 1, 28, 35, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (870, 1, 1, 29, 36, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (871, 1, 1, 30, 37, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (872, 1, 1, 31, 38, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (873, 1, 1, 32, 39, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (874, 1, 1, 33, 40, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (875, 1, 1, 34, 41, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (876, 1, 1, 35, 42, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (877, 1, 1, 36, 44, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (878, 1, 1, 37, 46, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (879, 1, 1, 38, 48, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (880, 1, 1, 39, 50, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (881, 1, 1, 40, 52, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (882, 1, 1, 41, 54, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (883, 1, 1, 42, 56, 0, 2, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (884, 1, 1, 43, 58, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (885, 1, 1, 44, 60, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (886, 1, 1, 45, 62, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (887, 1, 1, 46, 64, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (888, 1, 1, 47, 66, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (889, 1, 1, 48, 68, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (890, 1, 1, 49, 70, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (891, 1, 1, 50, 72, 0, 2, 2, 2, 0, 2);
INSERT INTO `player_levelupgains` VALUES (892, 1, 1, 51, 74, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (893, 1, 1, 52, 76, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (894, 1, 1, 53, 78, 0, 2, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (895, 1, 1, 54, 80, 0, 3, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (896, 1, 1, 55, 82, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (897, 1, 1, 56, 84, 0, 2, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (898, 1, 1, 57, 86, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (899, 1, 1, 58, 88, 0, 3, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (900, 1, 1, 59, 90, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (902, 4, 11, 1, 8, 22, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (903, 4, 11, 2, 17, 23, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (904, 4, 11, 3, 17, 24, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (905, 4, 11, 4, 17, 25, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (906, 4, 11, 5, 17, 26, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (907, 4, 11, 6, 17, 27, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (908, 4, 11, 7, 17, 13, 1, 0, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (909, 4, 11, 8, 17, 29, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (910, 4, 11, 9, 17, 30, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (911, 4, 11, 10, 17, 31, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (912, 4, 11, 11, 17, 32, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (913, 4, 11, 12, 17, 33, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (914, 4, 11, 13, 17, 34, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (915, 4, 11, 14, 17, 50, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (916, 4, 11, 15, 17, 36, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (917, 4, 11, 16, 17, 37, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (918, 4, 11, 17, 18, 38, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (919, 4, 11, 18, 19, 39, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (920, 4, 11, 19, 20, 40, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (921, 4, 11, 20, 21, 41, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (922, 4, 11, 21, 22, 27, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (923, 4, 11, 22, 23, 43, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (924, 4, 11, 23, 24, 59, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (925, 4, 11, 24, 25, 45, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (926, 4, 11, 25, 26, 45, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (927, 4, 11, 26, 27, 30, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (928, 4, 11, 27, 28, 45, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (929, 4, 11, 28, 29, 60, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (930, 4, 11, 29, 30, 45, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (931, 4, 11, 30, 31, 30, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (932, 4, 11, 31, 32, 60, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (933, 4, 11, 32, 33, 45, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (934, 4, 11, 33, 34, 30, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (935, 4, 11, 34, 35, 60, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (936, 4, 11, 35, 36, 30, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (937, 4, 11, 36, 37, 45, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (938, 4, 11, 37, 38, 60, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (939, 4, 11, 38, 39, 30, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (940, 4, 11, 39, 40, 60, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (941, 4, 11, 40, 41, 30, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (942, 4, 11, 41, 42, 60, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (943, 4, 11, 42, 43, 30, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (944, 4, 11, 43, 44, 60, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (945, 4, 11, 44, 45, 30, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (946, 4, 11, 45, 46, 60, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (947, 4, 11, 46, 47, 30, 1, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (948, 4, 11, 47, 48, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (949, 4, 11, 48, 49, 60, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (950, 4, 11, 49, 50, 30, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (951, 4, 11, 50, 51, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (952, 4, 11, 51, 52, 60, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (953, 4, 11, 52, 53, 30, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (954, 4, 11, 53, 54, 45, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (955, 4, 11, 54, 55, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (956, 4, 11, 55, 56, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (957, 4, 11, 56, 57, 45, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (958, 4, 11, 57, 58, 45, 1, 1, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (959, 4, 11, 58, 59, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (960, 4, 11, 59, 60, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (962, 4, 3, 1, 17, 20, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (963, 4, 3, 2, 17, 21, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (964, 4, 3, 3, 17, 22, 0, 2, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (965, 4, 3, 4, 17, 23, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (966, 4, 3, 5, 17, 24, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (967, 4, 3, 6, 17, 25, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (968, 4, 3, 7, 17, 26, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (969, 4, 3, 8, 17, 27, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (970, 4, 3, 9, 17, 28, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (971, 4, 3, 10, 17, 29, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (972, 4, 3, 11, 17, 30, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (973, 4, 3, 12, 17, 31, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (974, 4, 3, 13, 18, 32, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (975, 4, 3, 14, 19, 33, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (976, 4, 3, 15, 20, 34, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (977, 4, 3, 16, 21, 35, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (978, 4, 3, 17, 22, 36, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (979, 4, 3, 18, 23, 37, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (980, 4, 3, 19, 24, 38, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (981, 4, 3, 20, 25, 39, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (982, 4, 3, 21, 26, 40, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (983, 4, 3, 22, 27, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (984, 4, 3, 23, 28, 42, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (985, 4, 3, 24, 29, 43, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (986, 4, 3, 25, 30, 44, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (987, 4, 3, 26, 31, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (988, 4, 3, 27, 32, 45, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (989, 4, 3, 28, 33, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (990, 4, 3, 29, 34, 45, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (991, 4, 3, 30, 35, 45, 0, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (992, 4, 3, 31, 36, 45, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (993, 4, 3, 32, 37, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (994, 4, 3, 33, 38, 45, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (995, 4, 3, 34, 39, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (996, 4, 3, 35, 40, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (997, 4, 3, 36, 41, 45, 0, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (998, 4, 3, 37, 42, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (999, 4, 3, 38, 43, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1000, 4, 3, 39, 44, 45, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1001, 4, 3, 40, 45, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1002, 4, 3, 41, 46, 45, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1003, 4, 3, 42, 47, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1004, 4, 3, 43, 48, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1005, 4, 3, 44, 49, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1006, 4, 3, 45, 50, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1007, 4, 3, 46, 51, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1008, 4, 3, 47, 52, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1009, 4, 3, 48, 53, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1010, 4, 3, 49, 54, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1011, 4, 3, 50, 55, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1012, 4, 3, 51, 56, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1013, 4, 3, 52, 57, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1014, 4, 3, 53, 58, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1015, 4, 3, 54, 59, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1016, 4, 3, 55, 60, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1017, 4, 3, 56, 61, 45, 1, 3, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1018, 4, 3, 57, 62, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1019, 4, 3, 58, 63, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1020, 4, 3, 59, 64, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1022, 4, 5, 1, 15, 24, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1023, 4, 5, 2, 6, 25, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1024, 4, 5, 3, 15, 26, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1025, 4, 5, 4, 15, 27, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1026, 4, 5, 5, 15, 28, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1027, 4, 5, 6, 15, 29, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1028, 4, 5, 7, 15, 30, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1029, 4, 5, 8, 15, 31, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1030, 4, 5, 9, 15, 47, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1031, 4, 5, 10, 15, 18, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1032, 4, 5, 11, 15, 34, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1033, 4, 5, 12, 15, 35, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1034, 4, 5, 13, 15, 36, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1035, 4, 5, 14, 15, 37, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1036, 4, 5, 15, 15, 38, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1037, 4, 5, 16, 15, 54, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1038, 4, 5, 17, 15, 25, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1039, 4, 5, 18, 15, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1040, 4, 5, 19, 15, 42, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1041, 4, 5, 20, 15, 43, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1042, 4, 5, 21, 16, 59, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1043, 4, 5, 22, 17, 30, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1044, 4, 5, 23, 18, 61, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1045, 4, 5, 24, 19, 32, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1046, 4, 5, 25, 20, 63, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1047, 4, 5, 26, 21, 34, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1048, 4, 5, 27, 22, 65, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1049, 4, 5, 28, 23, 36, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1050, 4, 5, 29, 24, 52, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1051, 4, 5, 30, 25, 68, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1052, 4, 5, 31, 26, 39, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1053, 4, 5, 32, 27, 69, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1054, 4, 5, 33, 28, 54, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1055, 4, 5, 34, 29, 39, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1056, 4, 5, 35, 30, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1057, 4, 5, 36, 31, 69, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1058, 4, 5, 37, 32, 54, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1059, 4, 5, 38, 33, 39, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1060, 4, 5, 39, 34, 54, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1061, 4, 5, 40, 35, 69, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1062, 4, 5, 41, 36, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1063, 4, 5, 42, 37, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1064, 4, 5, 43, 38, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1065, 4, 5, 44, 39, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1066, 4, 5, 45, 40, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1067, 4, 5, 46, 41, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1068, 4, 5, 47, 42, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1069, 4, 5, 48, 43, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1070, 4, 5, 49, 44, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1071, 4, 5, 50, 45, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1072, 4, 5, 51, 46, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1073, 4, 5, 52, 47, 54, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1074, 4, 5, 53, 48, 54, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1075, 4, 5, 54, 49, 54, 0, 1, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (1076, 4, 5, 55, 50, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1077, 4, 5, 56, 51, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1078, 4, 5, 57, 52, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1079, 4, 5, 58, 53, 54, 1, 1, 0, 3, 3);
INSERT INTO `player_levelupgains` VALUES (1080, 4, 5, 59, 54, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1082, 4, 4, 1, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1083, 4, 4, 2, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1084, 4, 4, 3, 17, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1085, 4, 4, 4, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1086, 4, 4, 5, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1087, 4, 4, 6, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1088, 4, 4, 7, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1089, 4, 4, 8, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1090, 4, 4, 9, 17, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1091, 4, 4, 10, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1092, 4, 4, 11, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1093, 4, 4, 12, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1094, 4, 4, 13, 17, 0, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1095, 4, 4, 14, 17, 0, 1, 2, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1096, 4, 4, 15, 18, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1097, 4, 4, 16, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1098, 4, 4, 17, 20, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1099, 4, 4, 18, 21, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1100, 4, 4, 19, 22, 0, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1101, 4, 4, 20, 23, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1102, 4, 4, 21, 24, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1103, 4, 4, 22, 25, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1104, 4, 4, 23, 26, 0, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1105, 4, 4, 24, 27, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1106, 4, 4, 25, 28, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1107, 4, 4, 26, 29, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1108, 4, 4, 27, 30, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1109, 4, 4, 28, 31, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1110, 4, 4, 29, 32, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1111, 4, 4, 30, 33, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1112, 4, 4, 31, 34, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1113, 4, 4, 32, 35, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1114, 4, 4, 33, 36, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1115, 4, 4, 34, 37, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1116, 4, 4, 35, 38, 0, 2, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1117, 4, 4, 36, 39, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1118, 4, 4, 37, 40, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1119, 4, 4, 38, 41, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1120, 4, 4, 39, 42, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1121, 4, 4, 40, 43, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1122, 4, 4, 41, 44, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1123, 4, 4, 42, 45, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1124, 4, 4, 43, 46, 0, 1, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1125, 4, 4, 44, 47, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1126, 4, 4, 45, 48, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1127, 4, 4, 46, 49, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1128, 4, 4, 47, 50, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1129, 4, 4, 48, 51, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1130, 4, 4, 49, 52, 0, 2, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1131, 4, 4, 50, 53, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1132, 4, 4, 51, 54, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1133, 4, 4, 52, 55, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1134, 4, 4, 53, 56, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1135, 4, 4, 54, 57, 0, 1, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1136, 4, 4, 55, 58, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1137, 4, 4, 56, 59, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1138, 4, 4, 57, 60, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1139, 4, 4, 58, 61, 0, 2, 2, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1140, 4, 4, 59, 62, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1142, 4, 1, 1, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1143, 4, 1, 2, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1144, 4, 1, 3, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1145, 4, 1, 4, 19, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1146, 4, 1, 5, 19, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1147, 4, 1, 6, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1148, 4, 1, 7, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1149, 4, 1, 8, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1150, 4, 1, 9, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1151, 4, 1, 10, 19, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1152, 4, 1, 11, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1153, 4, 1, 12, 19, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1154, 4, 1, 13, 20, 0, 2, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1155, 4, 1, 14, 21, 0, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1156, 4, 1, 15, 22, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1157, 4, 1, 16, 23, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1158, 4, 1, 17, 24, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1159, 4, 1, 18, 25, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1160, 4, 1, 19, 26, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1161, 4, 1, 20, 27, 0, 1, 0, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1162, 4, 1, 21, 28, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1163, 4, 1, 22, 29, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1164, 4, 1, 23, 30, 0, 1, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1165, 4, 1, 24, 31, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1166, 4, 1, 25, 32, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1167, 4, 1, 26, 33, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1168, 4, 1, 27, 34, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1169, 4, 1, 28, 35, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1170, 4, 1, 29, 36, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1171, 4, 1, 30, 37, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1172, 4, 1, 31, 38, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1173, 4, 1, 32, 39, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1174, 4, 1, 33, 40, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1175, 4, 1, 34, 41, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1176, 4, 1, 35, 42, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1177, 4, 1, 36, 44, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1178, 4, 1, 37, 46, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1179, 4, 1, 38, 48, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1180, 4, 1, 39, 50, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1181, 4, 1, 40, 52, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1182, 4, 1, 41, 54, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1183, 4, 1, 42, 56, 0, 2, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1184, 4, 1, 43, 58, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1185, 4, 1, 44, 60, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1186, 4, 1, 45, 62, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1187, 4, 1, 46, 64, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1188, 4, 1, 47, 66, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1189, 4, 1, 48, 68, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1190, 4, 1, 49, 70, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1191, 4, 1, 50, 72, 0, 2, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1192, 4, 1, 51, 74, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1193, 4, 1, 52, 76, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1194, 4, 1, 53, 78, 0, 2, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1195, 4, 1, 54, 80, 0, 3, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1196, 4, 1, 55, 82, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1197, 4, 1, 56, 84, 0, 2, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1198, 4, 1, 57, 86, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1199, 4, 1, 58, 88, 0, 3, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1200, 4, 1, 59, 90, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1202, 2, 3, 1, 17, 6, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1203, 2, 3, 2, 17, 21, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1204, 2, 3, 3, 17, 8, 0, 2, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1205, 2, 3, 4, 17, 23, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1206, 2, 3, 5, 17, 10, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1207, 2, 3, 6, 17, 25, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1208, 2, 3, 7, 17, 26, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1209, 2, 3, 8, 17, 27, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1210, 2, 3, 9, 17, 28, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1211, 2, 3, 10, 17, 29, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1212, 2, 3, 11, 17, 30, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1213, 2, 3, 12, 17, 31, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1214, 2, 3, 13, 18, 32, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1215, 2, 3, 14, 19, 33, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1216, 2, 3, 15, 20, 34, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1217, 2, 3, 16, 21, 35, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1218, 2, 3, 17, 22, 36, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1219, 2, 3, 18, 23, 37, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1220, 2, 3, 19, 24, 38, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1221, 2, 3, 20, 25, 39, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1222, 2, 3, 21, 26, 40, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1223, 2, 3, 22, 27, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1224, 2, 3, 23, 28, 42, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1225, 2, 3, 24, 29, 43, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1226, 2, 3, 25, 30, 44, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1227, 2, 3, 26, 31, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1228, 2, 3, 27, 32, 45, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1229, 2, 3, 28, 33, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1230, 2, 3, 29, 34, 45, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1231, 2, 3, 30, 35, 45, 0, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1232, 2, 3, 31, 36, 45, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1233, 2, 3, 32, 37, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1234, 2, 3, 33, 38, 45, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1235, 2, 3, 34, 39, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1236, 2, 3, 35, 40, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1237, 2, 3, 36, 41, 45, 0, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1238, 2, 3, 37, 42, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1239, 2, 3, 38, 43, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1240, 2, 3, 39, 44, 45, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1241, 2, 3, 40, 45, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1242, 2, 3, 41, 46, 45, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1243, 2, 3, 42, 47, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1244, 2, 3, 43, 48, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1245, 2, 3, 44, 49, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1246, 2, 3, 45, 50, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1247, 2, 3, 46, 51, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1248, 2, 3, 47, 52, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1249, 2, 3, 48, 53, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1250, 2, 3, 49, 54, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1251, 2, 3, 50, 55, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1252, 2, 3, 51, 56, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1253, 2, 3, 52, 57, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1254, 2, 3, 53, 58, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1255, 2, 3, 54, 59, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1256, 2, 3, 55, 60, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1257, 2, 3, 56, 61, 45, 1, 3, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1258, 2, 3, 57, 62, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1259, 2, 3, 58, 63, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1260, 2, 3, 59, 64, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1262, 2, 4, 1, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1263, 2, 4, 2, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1264, 2, 4, 3, 17, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1265, 2, 4, 4, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1266, 2, 4, 5, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1267, 2, 4, 6, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1268, 2, 4, 7, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1269, 2, 4, 8, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1270, 2, 4, 9, 17, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1271, 2, 4, 10, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1272, 2, 4, 11, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1273, 2, 4, 12, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1274, 2, 4, 13, 17, 0, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1275, 2, 4, 14, 17, 0, 1, 2, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1276, 2, 4, 15, 18, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1277, 2, 4, 16, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1278, 2, 4, 17, 20, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1279, 2, 4, 18, 0, 0, 0, 0, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1280, 2, 4, 19, 0, 0, 0, 0, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1281, 2, 4, 20, 66, 0, 2, 5, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1282, 2, 4, 21, 24, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1283, 2, 4, 22, 25, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1284, 2, 4, 23, 26, 0, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1285, 2, 4, 24, 27, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1286, 2, 4, 25, 28, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1287, 2, 4, 26, 29, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1288, 2, 4, 27, 30, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1289, 2, 4, 28, 31, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1290, 2, 4, 29, 32, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1291, 2, 4, 30, 33, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1292, 2, 4, 31, 34, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1293, 2, 4, 32, 35, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1294, 2, 4, 33, 36, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1295, 2, 4, 34, 37, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1296, 2, 4, 35, 38, 0, 2, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1297, 2, 4, 36, 39, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1298, 2, 4, 37, 45, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1299, 2, 4, 38, 36, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1300, 2, 4, 39, 42, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1301, 2, 4, 40, 43, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1302, 2, 4, 41, 44, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1303, 2, 4, 42, 45, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1304, 2, 4, 43, 46, 0, 1, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1305, 2, 4, 44, 47, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1306, 2, 4, 45, 48, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1307, 2, 4, 46, 49, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1308, 2, 4, 47, 50, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1309, 2, 4, 48, 51, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1310, 2, 4, 49, 52, 0, 2, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1311, 2, 4, 50, 53, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1312, 2, 4, 51, 54, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1313, 2, 4, 52, 55, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1314, 2, 4, 53, 56, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1315, 2, 4, 54, 57, 0, 1, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1316, 2, 4, 55, 58, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1317, 2, 4, 56, 59, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1318, 2, 4, 57, 60, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1319, 2, 4, 58, 61, 0, 2, 2, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1320, 2, 4, 59, 62, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1322, 2, 7, 1, 17, 7, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1323, 2, 7, 2, 17, 8, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1324, 2, 7, 3, 17, 23, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1325, 2, 7, 4, 17, 24, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1326, 2, 7, 5, 17, 25, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1327, 2, 7, 6, 17, 26, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1328, 2, 7, 7, 17, 27, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1329, 2, 7, 8, 17, 43, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1330, 2, 7, 9, 17, 14, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1331, 2, 7, 10, 17, 30, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1332, 2, 7, 11, 17, 31, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1333, 2, 7, 12, 17, 32, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1334, 2, 7, 13, 17, 33, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1335, 2, 7, 14, 17, 34, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1336, 2, 7, 15, 17, 35, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1337, 2, 7, 16, 18, 36, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1338, 2, 7, 17, 19, 37, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1339, 2, 7, 18, 20, 38, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1340, 2, 7, 19, 21, 39, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1341, 2, 7, 20, 22, 40, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1342, 2, 7, 21, 23, 76, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1343, 2, 7, 22, 24, 7, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1344, 2, 7, 23, 25, 43, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1345, 2, 7, 24, 26, 44, 1, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1346, 2, 7, 25, 27, 89, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1347, 2, 7, 26, 28, 2, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1348, 2, 7, 27, 29, 47, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1349, 2, 7, 28, 30, 48, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1350, 2, 7, 29, 31, 102, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1351, 2, 7, 30, 32, 11, 2, 0, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1352, 2, 7, 31, 33, 108, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1353, 2, 7, 32, 34, 51, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1354, 2, 7, 33, 35, 36, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1355, 2, 7, 34, 36, 51, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1356, 2, 7, 35, 37, 68, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1357, 2, 7, 36, 38, 51, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1358, 2, 7, 37, 39, 52, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1359, 2, 7, 38, 40, 52, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1360, 2, 7, 39, 41, 50, 2, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1361, 2, 7, 40, 42, 32, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1362, 2, 7, 41, 43, 22, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1363, 2, 7, 42, 44, 13, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1364, 2, 7, 43, 45, 51, 2, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1365, 2, 7, 44, 46, 124, 1, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1366, 2, 7, 45, 47, 67, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1367, 2, 7, 46, 48, 52, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1368, 2, 7, 47, 49, 51, 2, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1369, 2, 7, 48, 50, 51, 1, 0, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1370, 2, 7, 49, 51, 36, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1371, 2, 7, 50, 52, 68, 2, 1, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1372, 2, 7, 51, 53, 51, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1373, 2, 7, 52, 54, 51, 2, 0, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1374, 2, 7, 53, 55, 22, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1375, 2, 7, 54, 56, 30, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1376, 2, 7, 55, 57, 51, 2, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1377, 2, 7, 56, 58, 103, 1, 1, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1378, 2, 7, 57, 59, 52, 2, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1379, 2, 7, 58, 60, 51, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1380, 2, 7, 59, 61, 79, 2, 1, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1382, 2, 9, 1, 15, 9, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1383, 2, 9, 2, 15, 24, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1384, 2, 9, 3, 15, 25, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1385, 2, 9, 4, 15, 26, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1386, 2, 9, 5, 15, 27, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1387, 2, 9, 6, 15, 28, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1388, 2, 9, 7, 15, 29, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1389, 2, 9, 8, 15, 30, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1390, 2, 9, 9, 15, 31, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1391, 2, 9, 10, 15, 32, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1392, 2, 9, 11, 15, 33, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1393, 2, 9, 12, 15, 34, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1394, 2, 9, 13, 15, 35, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1395, 2, 9, 14, 15, 36, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1396, 2, 9, 15, 15, 37, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1397, 2, 9, 16, 15, 38, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1398, 2, 9, 17, 16, 39, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1399, 2, 9, 18, 35, 40, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1400, 2, 9, 19, 12, 41, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1401, 2, 9, 20, 32, 42, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1402, 2, 9, 21, 0, 43, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1403, 2, 9, 22, 16, 44, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1404, 2, 9, 23, 22, 45, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1405, 2, 9, 24, 23, 46, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1406, 2, 9, 25, 24, 47, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1407, 2, 9, 26, 25, 48, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1408, 2, 9, 27, 26, 49, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1409, 2, 9, 28, 27, 50, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1410, 2, 9, 29, 28, 51, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1411, 2, 9, 30, 29, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1412, 2, 9, 31, 30, 51, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1413, 2, 9, 32, 21, 51, 0, 0, 0, 1, 3);
INSERT INTO `player_levelupgains` VALUES (1414, 2, 9, 33, 42, 51, 1, 1, 1, 2, 0);
INSERT INTO `player_levelupgains` VALUES (1415, 2, 9, 34, 33, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1416, 2, 9, 35, 34, 51, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1417, 2, 9, 36, 35, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1418, 2, 9, 37, 36, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1419, 2, 9, 38, 37, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1420, 2, 9, 39, 38, 51, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1421, 2, 9, 40, 39, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1422, 2, 9, 41, 20, 51, 0, 0, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1423, 2, 9, 42, 61, 51, 1, 1, 3, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1424, 2, 9, 43, 42, 51, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1425, 2, 9, 44, 43, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1426, 2, 9, 45, 44, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1427, 2, 9, 46, 45, 51, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1428, 2, 9, 47, 46, 51, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1429, 2, 9, 48, 47, 51, 1, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1430, 2, 9, 49, 48, 51, 0, 0, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1431, 2, 9, 50, 39, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1432, 2, 9, 51, 60, 51, 0, 0, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1433, 2, 9, 52, 51, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1434, 2, 9, 53, 32, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1435, 2, 9, 54, 73, 51, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1436, 2, 9, 55, 54, 51, 1, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1437, 2, 9, 56, 49, 51, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1438, 2, 9, 57, 52, 51, 1, 1, 2, 2, 4);
INSERT INTO `player_levelupgains` VALUES (1439, 2, 9, 58, 57, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1440, 2, 9, 59, 68, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1442, 2, 1, 1, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1443, 2, 1, 2, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1444, 2, 1, 3, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1445, 2, 1, 4, 19, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1446, 2, 1, 5, 19, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1447, 2, 1, 6, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1448, 2, 1, 7, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1449, 2, 1, 8, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1450, 2, 1, 9, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1451, 2, 1, 10, 19, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1452, 2, 1, 11, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1453, 2, 1, 12, 19, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1454, 2, 1, 13, 20, 0, 2, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1455, 2, 1, 14, 21, 0, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1456, 2, 1, 15, 22, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1457, 2, 1, 16, 23, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1458, 2, 1, 17, 24, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1459, 2, 1, 18, 25, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1460, 2, 1, 19, 26, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1461, 2, 1, 20, 27, 0, 1, 0, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1462, 2, 1, 21, 28, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1463, 2, 1, 22, 29, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1464, 2, 1, 23, 30, 0, 1, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1465, 2, 1, 24, 31, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1466, 2, 1, 25, 32, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1467, 2, 1, 26, 33, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1468, 2, 1, 27, 34, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1469, 2, 1, 28, 35, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1470, 2, 1, 29, 36, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1471, 2, 1, 30, 37, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1472, 2, 1, 31, 38, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1473, 2, 1, 32, 39, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1474, 2, 1, 33, 40, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1475, 2, 1, 34, 41, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1476, 2, 1, 35, 42, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1477, 2, 1, 36, 44, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1478, 2, 1, 37, 46, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1479, 2, 1, 38, 48, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1480, 2, 1, 39, 50, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1481, 2, 1, 40, 52, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1482, 2, 1, 41, 54, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1483, 2, 1, 42, 56, 0, 2, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1484, 2, 1, 43, 58, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1485, 2, 1, 44, 60, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1486, 2, 1, 45, 62, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1487, 2, 1, 46, 64, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1488, 2, 1, 47, 66, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1489, 2, 1, 48, 68, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1490, 2, 1, 49, 70, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1491, 2, 1, 50, 72, 0, 2, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1492, 2, 1, 51, 74, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1493, 2, 1, 52, 76, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1494, 2, 1, 53, 78, 0, 2, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1495, 2, 1, 54, 80, 0, 3, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1496, 2, 1, 55, 82, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1497, 2, 1, 56, 84, 0, 2, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1498, 2, 1, 57, 86, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1499, 2, 1, 58, 88, 0, 3, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1500, 2, 1, 59, 90, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1502, 6, 11, 1, 19, 8, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1503, 6, 11, 2, 16, 9, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1504, 6, 11, 3, 19, 10, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1505, 6, 11, 4, 18, 25, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1506, 6, 11, 5, 18, 26, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1507, 6, 11, 6, 17, 27, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1508, 6, 11, 7, 18, 13, 1, 0, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1509, 6, 11, 8, 18, 29, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1510, 6, 11, 9, 18, 30, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1511, 6, 11, 10, 18, 31, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1512, 6, 11, 11, 17, 32, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1513, 6, 11, 12, 18, 33, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1514, 6, 11, 13, 18, 34, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1515, 6, 11, 14, 19, 50, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1516, 6, 11, 15, 18, 36, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1517, 6, 11, 16, 18, 37, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1518, 6, 11, 17, 18, 38, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1519, 6, 11, 18, 19, 39, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1520, 6, 11, 19, 23, 40, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1521, 6, 11, 20, 22, 41, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1522, 6, 11, 21, 23, 27, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1523, 6, 11, 22, 24, 43, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1524, 6, 11, 23, 24, 59, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1525, 6, 11, 24, 26, 45, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1526, 6, 11, 25, 29, 45, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1527, 6, 11, 26, 28, 30, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1528, 6, 11, 27, 29, 45, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1529, 6, 11, 28, 29, 60, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1530, 6, 11, 29, 32, 45, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1531, 6, 11, 30, 32, 30, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1532, 6, 11, 31, 34, 60, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1533, 6, 11, 32, 36, 45, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1534, 6, 11, 33, 34, 30, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1535, 6, 11, 34, 37, 60, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1536, 6, 11, 35, 39, 30, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1537, 6, 11, 36, 38, 45, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1538, 6, 11, 37, 41, 60, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1539, 6, 11, 38, 40, 30, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1540, 6, 11, 39, 42, 60, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1541, 6, 11, 40, 44, 30, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1542, 6, 11, 41, 43, 60, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1543, 6, 11, 42, 46, 30, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1544, 6, 11, 43, 46, 60, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1545, 6, 11, 44, 47, 30, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1546, 6, 11, 45, 49, 60, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1547, 6, 11, 46, 49, 30, 1, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1548, 6, 11, 47, 49, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1549, 6, 11, 48, 53, 60, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1550, 6, 11, 49, 52, 30, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1551, 6, 11, 50, 54, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1552, 6, 11, 51, 55, 60, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1553, 6, 11, 52, 55, 30, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1554, 6, 11, 53, 57, 45, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1555, 6, 11, 54, 57, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1556, 6, 11, 55, 59, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1557, 6, 11, 56, 61, 45, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1558, 6, 11, 57, 60, 45, 1, 1, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1559, 6, 11, 58, 63, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1560, 6, 11, 59, 62, 45, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1562, 6, 3, 1, 17, 6, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1563, 6, 3, 2, 18, 21, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1564, 6, 3, 3, 18, 8, 0, 2, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1565, 6, 3, 4, 18, 23, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1566, 6, 3, 5, 17, 10, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1567, 6, 3, 6, 18, 25, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1568, 6, 3, 7, 18, 12, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1569, 6, 3, 8, 19, 27, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1570, 6, 3, 9, 16, 14, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1571, 6, 3, 10, 18, 29, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1572, 6, 3, 11, 18, 30, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1573, 6, 3, 12, 19, 31, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1574, 6, 3, 13, 18, 32, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1575, 6, 3, 14, 21, 33, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1576, 6, 3, 15, 21, 34, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1577, 6, 3, 16, 21, 35, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1578, 6, 3, 17, 24, 36, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1579, 6, 3, 18, 25, 37, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1580, 6, 3, 19, 24, 38, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1581, 6, 3, 20, 27, 39, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1582, 6, 3, 21, 26, 40, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1583, 6, 3, 22, 29, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1584, 6, 3, 23, 29, 42, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1585, 6, 3, 24, 31, 43, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1586, 6, 3, 25, 32, 44, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1587, 6, 3, 26, 31, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1588, 6, 3, 27, 34, 45, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1589, 6, 3, 28, 35, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1590, 6, 3, 29, 36, 45, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1591, 6, 3, 30, 37, 45, 0, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1592, 6, 3, 31, 37, 45, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1593, 6, 3, 32, 39, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1594, 6, 3, 33, 39, 45, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1595, 6, 3, 34, 42, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1596, 6, 3, 35, 42, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1597, 6, 3, 36, 42, 45, 0, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1598, 6, 3, 37, 46, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1599, 6, 3, 38, 44, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1600, 6, 3, 39, 46, 45, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1601, 6, 3, 40, 49, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1602, 6, 3, 41, 47, 45, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1603, 6, 3, 42, 50, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1604, 6, 3, 43, 50, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1605, 6, 3, 44, 51, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1606, 6, 3, 45, 54, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1607, 6, 3, 46, 52, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1608, 6, 3, 47, 55, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1609, 6, 3, 48, 56, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1610, 6, 3, 49, 56, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1611, 6, 3, 50, 58, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1612, 6, 3, 51, 59, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1613, 6, 3, 52, 60, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1614, 6, 3, 53, 61, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1615, 6, 3, 54, 61, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1616, 6, 3, 55, 63, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1617, 6, 3, 56, 65, 45, 1, 3, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1618, 6, 3, 57, 65, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1619, 6, 3, 58, 66, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1620, 6, 3, 59, 68, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1622, 6, 7, 1, 17, 7, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1623, 6, 7, 2, 19, 8, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1624, 6, 7, 3, 16, 23, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1625, 6, 7, 4, 19, 10, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1626, 6, 7, 5, 18, 11, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1627, 6, 7, 6, 18, 26, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1628, 6, 7, 7, 17, 27, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1629, 6, 7, 8, 18, 43, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1630, 6, 7, 9, 18, 14, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1631, 6, 7, 10, 18, 30, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1632, 6, 7, 11, 18, 31, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1633, 6, 7, 12, 17, 32, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1634, 6, 7, 13, 18, 33, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1635, 6, 7, 14, 18, 34, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1636, 6, 7, 15, 19, 35, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1637, 6, 7, 16, 18, 36, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1638, 6, 7, 17, 21, 37, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1639, 6, 7, 18, 21, 38, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1640, 6, 7, 19, 21, 39, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1641, 6, 7, 20, 24, 40, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1642, 6, 7, 21, 23, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1643, 6, 7, 22, 26, 42, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1644, 6, 7, 23, 27, 81, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1645, 6, 7, 24, 26, 6, 1, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1646, 6, 7, 25, 29, 45, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1647, 6, 7, 26, 29, 46, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1648, 6, 7, 27, 31, 47, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1649, 6, 7, 28, 32, 48, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1650, 6, 7, 29, 31, 49, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1651, 6, 7, 30, 34, 119, 2, 0, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1652, 6, 7, 31, 35, 52, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1653, 6, 7, 32, 36, 49, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1654, 6, 7, 33, 35, 40, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1655, 6, 7, 34, 39, 49, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1656, 6, 7, 35, 39, 0, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1657, 6, 7, 36, 40, 119, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1658, 6, 7, 37, 41, 13, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1659, 6, 7, 38, 42, 38, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1660, 6, 7, 39, 43, 103, 2, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1661, 6, 7, 40, 45, 51, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1662, 6, 7, 41, 44, 37, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1663, 6, 7, 42, 45, 51, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1664, 6, 7, 43, 49, 67, 2, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1665, 6, 7, 44, 48, 36, 1, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1666, 6, 7, 45, 50, 67, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1667, 6, 7, 46, 50, 51, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1668, 6, 7, 47, 51, 36, 2, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1669, 6, 7, 48, 53, 67, 1, 0, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1670, 6, 7, 49, 52, 36, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1671, 6, 7, 50, 55, 67, 2, 1, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1672, 6, 7, 51, 57, 52, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1673, 6, 7, 52, 56, 51, 2, 0, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1674, 6, 7, 53, 58, 23, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1675, 6, 7, 54, 59, 29, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1676, 6, 7, 55, 59, 51, 2, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1677, 6, 7, 56, 60, 103, 1, 1, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1678, 6, 7, 57, 62, 51, 2, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1679, 6, 7, 58, 64, 27, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1680, 6, 7, 59, 65, 25, 2, 1, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1682, 6, 1, 1, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1683, 6, 1, 2, 20, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1684, 6, 1, 3, 21, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1685, 6, 1, 4, 19, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1686, 6, 1, 5, 20, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1687, 6, 1, 6, 21, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1688, 6, 1, 7, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1689, 6, 1, 8, 21, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1690, 6, 1, 9, 20, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1691, 6, 1, 10, 19, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1692, 6, 1, 11, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1693, 6, 1, 12, 20, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1694, 6, 1, 13, 22, 0, 2, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1695, 6, 1, 14, 21, 0, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1696, 6, 1, 15, 25, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1697, 6, 1, 16, 24, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1698, 6, 1, 17, 24, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1699, 6, 1, 18, 28, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1700, 6, 1, 19, 25, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1701, 6, 1, 20, 29, 0, 1, 0, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1702, 6, 1, 21, 30, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1703, 6, 1, 22, 30, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1704, 6, 1, 23, 31, 0, 1, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1705, 6, 1, 24, 34, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1706, 6, 1, 25, 32, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1707, 6, 1, 26, 36, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1708, 6, 1, 27, 35, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1709, 6, 1, 28, 37, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1710, 6, 1, 29, 39, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1711, 6, 1, 30, 37, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1712, 6, 1, 31, 41, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1713, 6, 1, 32, 40, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1714, 6, 1, 33, 42, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1715, 6, 1, 34, 44, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1716, 6, 1, 35, 43, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1717, 6, 1, 36, 46, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1718, 6, 1, 37, 50, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1719, 6, 1, 38, 50, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1720, 6, 1, 39, 51, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1721, 6, 1, 40, 56, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1722, 6, 1, 41, 57, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1723, 6, 1, 42, 59, 0, 2, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1724, 6, 1, 43, 60, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1725, 6, 1, 44, 63, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1726, 6, 1, 45, 66, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1727, 6, 1, 46, 67, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1728, 6, 1, 47, 68, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1729, 6, 1, 48, 72, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1730, 6, 1, 49, 74, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1731, 6, 1, 50, 76, 0, 2, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1732, 6, 1, 51, 76, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1733, 6, 1, 52, 80, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1734, 6, 1, 53, 83, 0, 2, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1735, 6, 1, 54, 84, 0, 3, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1736, 6, 1, 55, 86, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1737, 6, 1, 56, 88, 0, 2, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1738, 6, 1, 57, 91, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1739, 6, 1, 58, 92, 0, 3, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1740, 6, 1, 59, 94, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1742, 8, 3, 1, 17, 6, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1743, 8, 3, 2, 17, 21, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1744, 8, 3, 3, 17, 8, 0, 2, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1745, 8, 3, 4, 17, 23, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1746, 8, 3, 5, 17, 10, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1747, 8, 3, 6, 17, 25, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1748, 8, 3, 7, 17, 12, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1749, 8, 3, 8, 17, 27, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1750, 8, 3, 9, 17, 28, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1751, 8, 3, 10, 17, 29, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1752, 8, 3, 11, 17, 30, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1753, 8, 3, 12, 17, 31, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1754, 8, 3, 13, 18, 32, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1755, 8, 3, 14, 19, 33, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1756, 8, 3, 15, 20, 34, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1757, 8, 3, 16, 21, 35, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1758, 8, 3, 17, 22, 36, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1759, 8, 3, 18, 23, 37, 0, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1760, 8, 3, 19, 24, 38, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1761, 8, 3, 20, 25, 39, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1762, 8, 3, 21, 26, 40, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1763, 8, 3, 22, 27, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1764, 8, 3, 23, 28, 42, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1765, 8, 3, 24, 29, 43, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1766, 8, 3, 25, 30, 44, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1767, 8, 3, 26, 31, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1768, 8, 3, 27, 32, 45, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1769, 8, 3, 28, 33, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1770, 8, 3, 29, 34, 45, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1771, 8, 3, 30, 35, 45, 0, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1772, 8, 3, 31, 36, 45, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1773, 8, 3, 32, 37, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1774, 8, 3, 33, 38, 45, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1775, 8, 3, 34, 39, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1776, 8, 3, 35, 40, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1777, 8, 3, 36, 41, 45, 0, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1778, 8, 3, 37, 42, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1779, 8, 3, 38, 43, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1780, 8, 3, 39, 44, 45, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1781, 8, 3, 40, 45, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1782, 8, 3, 41, 46, 45, 0, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1783, 8, 3, 42, 47, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1784, 8, 3, 43, 48, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1785, 8, 3, 44, 49, 45, 0, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1786, 8, 3, 45, 50, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1787, 8, 3, 46, 51, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1788, 8, 3, 47, 52, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1789, 8, 3, 48, 53, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1790, 8, 3, 49, 54, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1791, 8, 3, 50, 55, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1792, 8, 3, 51, 56, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1793, 8, 3, 52, 57, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1794, 8, 3, 53, 58, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1795, 8, 3, 54, 59, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1796, 8, 3, 55, 60, 45, 1, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1797, 8, 3, 56, 61, 45, 1, 3, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1798, 8, 3, 57, 62, 45, 0, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1799, 8, 3, 58, 63, 45, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1800, 8, 3, 59, 64, 45, 1, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1802, 8, 8, 1, 15, 11, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1803, 8, 8, 2, 15, 26, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1804, 8, 8, 3, 15, 27, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1805, 8, 8, 4, 15, 28, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1806, 8, 8, 5, 15, 29, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1807, 8, 8, 6, 15, 30, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1808, 8, 8, 7, 15, 16, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1809, 8, 8, 8, 15, 47, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1810, 8, 8, 9, 15, 33, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1811, 8, 8, 10, 15, 34, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1812, 8, 8, 11, 15, 35, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1813, 8, 8, 12, 15, 36, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1814, 8, 8, 13, 15, 37, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1815, 8, 8, 14, 15, 38, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1816, 8, 8, 15, 15, 39, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1817, 8, 8, 16, 15, 25, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1818, 8, 8, 17, 15, 56, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1819, 8, 8, 18, 15, 27, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1820, 8, 8, 19, 15, 58, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1821, 8, 8, 20, 15, 29, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1822, 8, 8, 21, 15, 60, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1823, 8, 8, 22, 15, 31, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1824, 8, 8, 23, 16, 62, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1825, 8, 8, 24, 17, 33, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1826, 8, 8, 25, 18, 64, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1827, 8, 8, 26, 19, 50, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1828, 8, 8, 27, 20, 36, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1829, 8, 8, 28, 21, 66, 0, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1830, 8, 8, 29, 22, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1831, 8, 8, 30, 23, 36, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1832, 8, 8, 31, 24, 66, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1833, 8, 8, 32, 25, 51, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1834, 8, 8, 33, 26, 36, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1835, 8, 8, 34, 27, 51, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1836, 8, 8, 35, 28, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1837, 8, 8, 36, 29, 66, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1838, 8, 8, 37, 30, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1839, 8, 8, 38, 31, 51, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1840, 8, 8, 39, 32, 36, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1841, 8, 8, 40, 33, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1842, 8, 8, 41, 34, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1843, 8, 8, 42, 35, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1844, 8, 8, 43, 36, 51, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1845, 8, 8, 44, 37, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1846, 8, 8, 45, 38, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1847, 8, 8, 46, 79, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1848, 8, 8, 47, 10, 66, 0, 0, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (1849, 8, 8, 48, 31, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1850, 8, 8, 49, 42, 36, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1851, 8, 8, 50, 43, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1852, 8, 8, 51, 44, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1853, 8, 8, 52, 45, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1854, 8, 8, 53, 46, 51, 1, 0, 1, 3, 2);
INSERT INTO `player_levelupgains` VALUES (1855, 8, 8, 54, 47, 66, 0, 0, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1856, 8, 8, 55, 48, 39, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1857, 8, 8, 56, 49, 48, 0, 0, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (1858, 8, 8, 57, 50, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1859, 8, 8, 58, 42, 51, 0, 1, 0, 3, 3);
INSERT INTO `player_levelupgains` VALUES (1860, 8, 8, 59, 61, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1862, 8, 5, 1, 15, 10, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1863, 8, 5, 2, 15, 11, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1864, 8, 5, 3, 15, 26, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1865, 8, 5, 4, 15, 27, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1866, 8, 5, 5, 15, 28, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1867, 8, 5, 6, 15, 29, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1868, 8, 5, 7, 15, 30, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1869, 8, 5, 8, 15, 31, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1870, 8, 5, 9, 15, 47, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1871, 8, 5, 10, 15, 18, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1872, 8, 5, 11, 15, 34, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1873, 8, 5, 12, 15, 35, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1874, 8, 5, 13, 15, 36, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1875, 8, 5, 14, 15, 37, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1876, 8, 5, 15, 15, 38, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1877, 8, 5, 16, 15, 54, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1878, 8, 5, 17, 15, 25, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1879, 8, 5, 18, 15, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1880, 8, 5, 19, 15, 42, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1881, 8, 5, 20, 15, 43, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1882, 8, 5, 21, 16, 59, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1883, 8, 5, 22, 17, 30, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1884, 8, 5, 23, 18, 61, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1885, 8, 5, 24, 19, 32, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1886, 8, 5, 25, 20, 63, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1887, 8, 5, 26, 21, 34, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1888, 8, 5, 27, 22, 65, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1889, 8, 5, 28, 23, 36, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1890, 8, 5, 29, 24, 52, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1891, 8, 5, 30, 25, 68, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1892, 8, 5, 31, 26, 39, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1893, 8, 5, 32, 27, 69, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1894, 8, 5, 33, 28, 54, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1895, 8, 5, 34, 29, 39, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1896, 8, 5, 35, 30, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1897, 8, 5, 36, 31, 69, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1898, 8, 5, 37, 32, 54, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1899, 8, 5, 38, 33, 39, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1900, 8, 5, 39, 34, 54, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (1901, 8, 5, 40, 35, 69, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1902, 8, 5, 41, 36, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1903, 8, 5, 42, 37, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1904, 8, 5, 43, 38, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1905, 8, 5, 44, 39, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1906, 8, 5, 45, 40, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1907, 8, 5, 46, 41, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1908, 8, 5, 47, 42, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1909, 8, 5, 48, 93, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1910, 8, 5, 49, 14, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1911, 8, 5, 50, 25, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1912, 8, 5, 51, 46, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1913, 8, 5, 52, 47, 54, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1914, 8, 5, 53, 48, 54, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1915, 8, 5, 54, 49, 54, 0, 1, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (1916, 8, 5, 55, 50, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1917, 8, 5, 56, 51, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (1918, 8, 5, 57, 52, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1919, 8, 5, 58, 53, 54, 1, 1, 0, 3, 3);
INSERT INTO `player_levelupgains` VALUES (1920, 8, 5, 59, 54, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (1922, 8, 4, 1, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1923, 8, 4, 2, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1924, 8, 4, 3, 17, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1925, 8, 4, 4, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1926, 8, 4, 5, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1927, 8, 4, 6, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1928, 8, 4, 7, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1929, 8, 4, 8, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1930, 8, 4, 9, 17, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1931, 8, 4, 10, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1932, 8, 4, 11, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1933, 8, 4, 12, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1934, 8, 4, 13, 17, 0, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1935, 8, 4, 14, 17, 0, 1, 2, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1936, 8, 4, 15, 18, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1937, 8, 4, 16, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1938, 8, 4, 17, 20, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1939, 8, 4, 18, 21, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1940, 8, 4, 19, 22, 0, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1941, 8, 4, 20, 23, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1942, 8, 4, 21, 24, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1943, 8, 4, 22, 25, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1944, 8, 4, 23, 26, 0, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1945, 8, 4, 24, 27, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1946, 8, 4, 25, 28, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1947, 8, 4, 26, 29, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1948, 8, 4, 27, 30, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1949, 8, 4, 28, 31, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1950, 8, 4, 29, 32, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1951, 8, 4, 30, 33, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1952, 8, 4, 31, 34, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1953, 8, 4, 32, 35, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1954, 8, 4, 33, 36, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1955, 8, 4, 34, 37, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1956, 8, 4, 35, 38, 0, 2, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1957, 8, 4, 36, 39, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1958, 8, 4, 37, 40, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1959, 8, 4, 38, 41, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1960, 8, 4, 39, 42, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1961, 8, 4, 40, 43, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1962, 8, 4, 41, 44, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1963, 8, 4, 42, 45, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1964, 8, 4, 43, 46, 0, 1, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1965, 8, 4, 44, 47, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1966, 8, 4, 45, 48, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1967, 8, 4, 46, 49, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1968, 8, 4, 47, 50, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1969, 8, 4, 48, 51, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1970, 8, 4, 49, 52, 0, 2, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1971, 8, 4, 50, 53, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1972, 8, 4, 51, 54, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1973, 8, 4, 52, 55, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1974, 8, 4, 53, 56, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1975, 8, 4, 54, 57, 0, 1, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (1976, 8, 4, 55, 58, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1977, 8, 4, 56, 59, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1978, 8, 4, 57, 60, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1979, 8, 4, 58, 61, 0, 2, 2, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1980, 8, 4, 59, 62, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1982, 8, 7, 1, 17, 7, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1983, 8, 7, 2, 17, 8, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1984, 8, 7, 3, 17, 23, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1985, 8, 7, 4, 17, 10, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1986, 8, 7, 5, 17, 25, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1987, 8, 7, 6, 17, 26, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1988, 8, 7, 7, 17, 27, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (1989, 8, 7, 8, 17, 43, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1990, 8, 7, 9, 17, 14, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (1991, 8, 7, 10, 17, 30, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1992, 8, 7, 11, 17, 31, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1993, 8, 7, 12, 17, 32, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1994, 8, 7, 13, 17, 33, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1995, 8, 7, 14, 17, 34, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (1996, 8, 7, 15, 17, 35, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1997, 8, 7, 16, 18, 36, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1998, 8, 7, 17, 19, 37, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (1999, 8, 7, 18, 20, 66, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2000, 8, 7, 19, 21, 11, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2001, 8, 7, 20, 22, 40, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2002, 8, 7, 21, 23, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2003, 8, 7, 22, 24, 42, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2004, 8, 7, 23, 25, 43, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2005, 8, 7, 24, 26, 44, 1, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2006, 8, 7, 25, 27, 88, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2007, 8, 7, 26, 28, 49, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2008, 8, 7, 27, 29, 49, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2009, 8, 7, 28, 30, 0, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2010, 8, 7, 29, 31, 49, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2011, 8, 7, 30, 32, 120, 2, 0, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2012, 8, 7, 31, 33, 51, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2013, 8, 7, 32, 34, 61, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2014, 8, 7, 33, 35, 27, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2015, 8, 7, 34, 36, 51, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2016, 8, 7, 35, 37, 57, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2017, 8, 7, 36, 38, 61, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2018, 8, 7, 37, 39, 52, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2019, 8, 7, 38, 40, 36, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2020, 8, 7, 39, 41, 38, 2, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2021, 8, 7, 40, 42, 28, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2022, 8, 7, 41, 43, 56, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2023, 8, 7, 42, 44, 33, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2024, 8, 7, 43, 45, 30, 2, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2025, 8, 7, 44, 46, 34, 1, 0, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2026, 8, 7, 45, 47, 64, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2027, 8, 7, 46, 48, 144, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2028, 8, 7, 47, 49, 36, 2, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2029, 8, 7, 48, 50, 53, 1, 0, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2030, 8, 7, 49, 51, 50, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2031, 8, 7, 50, 52, 50, 2, 1, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2032, 8, 7, 51, 53, 27, 1, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2033, 8, 7, 52, 54, 31, 2, 0, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2034, 8, 7, 53, 55, 21, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2035, 8, 7, 54, 56, 30, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2036, 8, 7, 55, 57, 33, 2, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2037, 8, 7, 56, 58, 65, 1, 1, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2038, 8, 7, 57, 59, 48, 2, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2039, 8, 7, 58, 60, 49, 1, 1, 2, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2040, 8, 7, 59, 61, 49, 2, 1, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2042, 8, 1, 1, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2043, 8, 1, 2, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2044, 8, 1, 3, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2045, 8, 1, 4, 19, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2046, 8, 1, 5, 19, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2047, 8, 1, 6, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2048, 8, 1, 7, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2049, 8, 1, 8, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2050, 8, 1, 9, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2051, 8, 1, 10, 19, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2052, 8, 1, 11, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2053, 8, 1, 12, 19, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2054, 8, 1, 13, 20, 0, 2, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2055, 8, 1, 14, 21, 0, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2056, 8, 1, 15, 22, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2057, 8, 1, 16, 23, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2058, 8, 1, 17, 24, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2059, 8, 1, 18, 25, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2060, 8, 1, 19, 26, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2061, 8, 1, 20, 27, 0, 1, 0, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2062, 8, 1, 21, 28, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2063, 8, 1, 22, 29, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2064, 8, 1, 23, 30, 0, 1, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2065, 8, 1, 24, 31, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2066, 8, 1, 25, 32, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2067, 8, 1, 26, 33, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2068, 8, 1, 27, 34, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2069, 8, 1, 28, 35, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2070, 8, 1, 29, 36, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2071, 8, 1, 30, 37, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2072, 8, 1, 31, 38, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2073, 8, 1, 32, 39, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2074, 8, 1, 33, 40, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2075, 8, 1, 34, 41, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2076, 8, 1, 35, 42, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2077, 8, 1, 36, 44, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2078, 8, 1, 37, 46, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2079, 8, 1, 38, 48, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2080, 8, 1, 39, 50, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2081, 8, 1, 40, 52, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2082, 8, 1, 41, 59, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2083, 8, 1, 42, 51, 0, 2, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2084, 8, 1, 43, 58, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2085, 8, 1, 44, 110, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2086, 8, 1, 45, 12, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2087, 8, 1, 46, 64, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2088, 8, 1, 47, 66, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2089, 8, 1, 48, 68, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2090, 8, 1, 49, 70, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2091, 8, 1, 50, 72, 0, 2, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2092, 8, 1, 51, 74, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2093, 8, 1, 52, 76, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2094, 8, 1, 53, 78, 0, 2, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2095, 8, 1, 54, 80, 0, 3, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2096, 8, 1, 55, 82, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2097, 8, 1, 56, 84, 0, 2, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2098, 8, 1, 57, 86, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2099, 8, 1, 58, 88, 0, 3, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2100, 8, 1, 59, 90, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2102, 5, 8, 1, 15, 25, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2103, 5, 8, 2, 15, 26, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2104, 5, 8, 3, 15, 27, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2105, 5, 8, 4, 15, 28, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2106, 5, 8, 5, 15, 29, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2107, 5, 8, 6, 15, 30, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2108, 5, 8, 7, 15, 16, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2109, 5, 8, 8, 15, 47, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2110, 5, 8, 9, 15, 33, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2111, 5, 8, 10, 15, 34, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2112, 5, 8, 11, 15, 35, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2113, 5, 8, 12, 15, 36, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2114, 5, 8, 13, 15, 37, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2115, 5, 8, 14, 15, 38, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2116, 5, 8, 15, 15, 39, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2117, 5, 8, 16, 15, 25, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2118, 5, 8, 17, 15, 56, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2119, 5, 8, 18, 15, 27, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2120, 5, 8, 19, 15, 58, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2121, 5, 8, 20, 15, 29, 1, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2122, 5, 8, 21, 15, 60, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2123, 5, 8, 22, 15, 31, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2124, 5, 8, 23, 16, 62, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2125, 5, 8, 24, 17, 33, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2126, 5, 8, 25, 18, 64, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2127, 5, 8, 26, 19, 50, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2128, 5, 8, 27, 20, 36, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2129, 5, 8, 28, 21, 66, 0, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2130, 5, 8, 29, 22, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2131, 5, 8, 30, 23, 36, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2132, 5, 8, 31, 24, 66, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2133, 5, 8, 32, 25, 51, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2134, 5, 8, 33, 26, 36, 1, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2135, 5, 8, 34, 27, 51, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2136, 5, 8, 35, 28, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2137, 5, 8, 36, 29, 66, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2138, 5, 8, 37, 30, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2139, 5, 8, 38, 31, 51, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2140, 5, 8, 39, 32, 36, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2141, 5, 8, 40, 33, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2142, 5, 8, 41, 34, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2143, 5, 8, 42, 35, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2144, 5, 8, 43, 36, 51, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2145, 5, 8, 44, 37, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2146, 5, 8, 45, 38, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2147, 5, 8, 46, 39, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2148, 5, 8, 47, 40, 66, 0, 0, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (2149, 5, 8, 48, 41, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2150, 5, 8, 49, 42, 36, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2151, 5, 8, 50, 43, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2152, 5, 8, 51, 44, 51, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2153, 5, 8, 52, 45, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2154, 5, 8, 53, 46, 51, 1, 0, 1, 3, 2);
INSERT INTO `player_levelupgains` VALUES (2155, 5, 8, 54, 47, 51, 0, 0, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (2156, 5, 8, 55, 48, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2157, 5, 8, 56, 49, 51, 0, 0, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (2158, 5, 8, 57, 50, 51, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2159, 5, 8, 58, 51, 51, 0, 1, 0, 3, 3);
INSERT INTO `player_levelupgains` VALUES (2160, 5, 8, 59, 52, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2162, 5, 5, 1, 15, 24, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2163, 5, 5, 2, 15, 25, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2164, 5, 5, 3, 15, 26, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2165, 5, 5, 4, 15, 27, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2166, 5, 5, 5, 15, 28, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2167, 5, 5, 6, 15, 29, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2168, 5, 5, 7, 15, 30, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2169, 5, 5, 8, 15, 31, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2170, 5, 5, 9, 15, 47, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2171, 5, 5, 10, 15, 18, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2172, 5, 5, 11, 15, 34, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2173, 5, 5, 12, 15, 35, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2174, 5, 5, 13, 15, 36, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2175, 5, 5, 14, 15, 37, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2176, 5, 5, 15, 15, 38, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2177, 5, 5, 16, 15, 54, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2178, 5, 5, 17, 15, 25, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2179, 5, 5, 18, 15, 41, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2180, 5, 5, 19, 15, 42, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2181, 5, 5, 20, 15, 43, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2182, 5, 5, 21, 16, 59, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2183, 5, 5, 22, 17, 30, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2184, 5, 5, 23, 18, 61, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2185, 5, 5, 24, 19, 32, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2186, 5, 5, 25, 20, 63, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2187, 5, 5, 26, 21, 34, 0, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2188, 5, 5, 27, 22, 65, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2189, 5, 5, 28, 23, 36, 1, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2190, 5, 5, 29, 24, 52, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2191, 5, 5, 30, 25, 68, 0, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2192, 5, 5, 31, 26, 39, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2193, 5, 5, 32, 27, 69, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2194, 5, 5, 33, 28, 54, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2195, 5, 5, 34, 29, 39, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2196, 5, 5, 35, 30, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2197, 5, 5, 36, 31, 69, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2198, 5, 5, 37, 32, 54, 0, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2199, 5, 5, 38, 33, 39, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2200, 5, 5, 39, 34, 54, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2201, 5, 5, 40, 35, 69, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2202, 5, 5, 41, 36, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2203, 5, 5, 42, 37, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2204, 5, 5, 43, 38, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2205, 5, 5, 44, 39, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2206, 5, 5, 45, 40, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2207, 5, 5, 46, 41, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2208, 5, 5, 47, 42, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (2209, 5, 5, 48, 43, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2210, 5, 5, 49, 44, 54, 1, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2211, 5, 5, 50, 45, 54, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2212, 5, 5, 51, 46, 54, 0, 0, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2213, 5, 5, 52, 47, 54, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2214, 5, 5, 53, 48, 54, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (2215, 5, 5, 54, 49, 54, 0, 1, 0, 3, 2);
INSERT INTO `player_levelupgains` VALUES (2216, 5, 5, 55, 50, 54, 1, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2217, 5, 5, 56, 51, 54, 0, 1, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (2218, 5, 5, 57, 52, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2219, 5, 5, 58, 53, 54, 1, 1, 0, 3, 3);
INSERT INTO `player_levelupgains` VALUES (2220, 5, 5, 59, 54, 54, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2222, 5, 4, 1, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2223, 5, 4, 2, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2224, 5, 4, 3, 17, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2225, 5, 4, 4, 17, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2226, 5, 4, 5, 17, 0, 0, 1, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2227, 5, 4, 6, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2228, 5, 4, 7, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2229, 5, 4, 8, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2230, 5, 4, 9, 17, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2231, 5, 4, 10, 17, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2232, 5, 4, 11, 17, 0, 1, 1, 0, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2233, 5, 4, 12, 17, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2234, 5, 4, 13, 17, 0, 0, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2235, 5, 4, 14, 17, 0, 1, 2, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2236, 5, 4, 15, 18, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2237, 5, 4, 16, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2238, 5, 4, 17, 20, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2239, 5, 4, 18, 21, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2240, 5, 4, 19, 22, 0, 0, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2241, 5, 4, 20, 23, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2242, 5, 4, 21, 24, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2243, 5, 4, 22, 25, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2244, 5, 4, 23, 26, 0, 1, 1, 0, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2245, 5, 4, 24, 27, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2246, 5, 4, 25, 28, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2247, 5, 4, 26, 29, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2248, 5, 4, 27, 30, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2249, 5, 4, 28, 31, 0, 0, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2250, 5, 4, 29, 32, 0, 1, 2, 0, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2251, 5, 4, 30, 33, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2252, 5, 4, 31, 34, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2253, 5, 4, 32, 35, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2254, 5, 4, 33, 36, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2255, 5, 4, 34, 37, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2256, 5, 4, 35, 38, 0, 2, 2, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2257, 5, 4, 36, 39, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2258, 5, 4, 37, 40, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2259, 5, 4, 38, 41, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2260, 5, 4, 39, 42, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2261, 5, 4, 40, 43, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2262, 5, 4, 41, 44, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2263, 5, 4, 42, 45, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2264, 5, 4, 43, 46, 0, 1, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2265, 5, 4, 44, 47, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2266, 5, 4, 45, 48, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2267, 5, 4, 46, 49, 0, 1, 2, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2268, 5, 4, 47, 50, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2269, 5, 4, 48, 51, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2270, 5, 4, 49, 52, 0, 2, 3, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2271, 5, 4, 50, 53, 0, 1, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2272, 5, 4, 51, 54, 0, 1, 2, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2273, 5, 4, 52, 55, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2274, 5, 4, 53, 56, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2275, 5, 4, 54, 57, 0, 1, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2276, 5, 4, 55, 58, 0, 1, 3, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2277, 5, 4, 56, 59, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2278, 5, 4, 57, 60, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2279, 5, 4, 58, 61, 0, 2, 2, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2280, 5, 4, 59, 62, 0, 1, 3, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2282, 5, 9, 1, 15, 23, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2283, 5, 9, 2, 15, 24, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2284, 5, 9, 3, 15, 25, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2285, 5, 9, 4, 15, 26, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2286, 5, 9, 5, 15, 27, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2287, 5, 9, 6, 15, 28, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2288, 5, 9, 7, 15, 29, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2289, 5, 9, 8, 15, 30, 0, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2290, 5, 9, 9, 15, 31, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2291, 5, 9, 10, 15, 32, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2292, 5, 9, 11, 15, 33, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2293, 5, 9, 12, 15, 34, 1, 0, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2294, 5, 9, 13, 15, 35, 0, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2295, 5, 9, 14, 15, 36, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2296, 5, 9, 15, 15, 37, 1, 1, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2297, 5, 9, 16, 15, 38, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2298, 5, 9, 17, 16, 39, 0, 0, 0, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2299, 5, 9, 18, 17, 40, 1, 1, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2300, 5, 9, 19, 18, 41, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2301, 5, 9, 20, 19, 42, 0, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2302, 5, 9, 21, 20, 43, 1, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2303, 5, 9, 22, 21, 44, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2304, 5, 9, 23, 22, 45, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2305, 5, 9, 24, 23, 46, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2306, 5, 9, 25, 24, 47, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2307, 5, 9, 26, 25, 48, 1, 0, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2308, 5, 9, 27, 26, 49, 0, 1, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2309, 5, 9, 28, 27, 50, 1, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2310, 5, 9, 29, 28, 51, 0, 1, 0, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2311, 5, 9, 30, 29, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2312, 5, 9, 31, 30, 51, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2313, 5, 9, 32, 31, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2314, 5, 9, 33, 32, 51, 1, 1, 0, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2315, 5, 9, 34, 33, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2316, 5, 9, 35, 24, 51, 1, 1, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (2317, 5, 9, 36, 45, 51, 0, 1, 2, 2, 0);
INSERT INTO `player_levelupgains` VALUES (2318, 5, 9, 37, 36, 51, 0, 0, 1, 1, 2);
INSERT INTO `player_levelupgains` VALUES (2319, 5, 9, 38, 37, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2320, 5, 9, 39, 38, 51, 0, 0, 1, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2321, 5, 9, 40, 39, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2322, 5, 9, 41, 30, 51, 0, 0, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (2323, 5, 9, 42, 51, 51, 1, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2324, 5, 9, 43, 42, 51, 0, 0, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2325, 5, 9, 44, 43, 51, 1, 1, 0, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2326, 5, 9, 45, 44, 51, 0, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2327, 5, 9, 46, 45, 51, 1, 0, 1, 1, 3);
INSERT INTO `player_levelupgains` VALUES (2328, 5, 9, 47, 46, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2329, 5, 9, 48, 47, 51, 1, 1, 1, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2330, 5, 9, 49, 28, 51, 0, 0, 1, 2, 3);
INSERT INTO `player_levelupgains` VALUES (2331, 5, 9, 50, 59, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2332, 5, 9, 51, 60, 51, 0, 0, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2333, 5, 9, 52, 51, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2334, 5, 9, 53, 42, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2335, 5, 9, 54, 43, 51, 0, 0, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (2336, 5, 9, 55, 74, 51, 1, 1, 2, 2, 1);
INSERT INTO `player_levelupgains` VALUES (2337, 5, 9, 56, 55, 51, 0, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2338, 5, 9, 57, 46, 51, 1, 1, 0, 2, 3);
INSERT INTO `player_levelupgains` VALUES (2339, 5, 9, 58, 67, 51, 0, 0, 2, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2340, 5, 9, 59, 58, 51, 1, 1, 1, 2, 2);
INSERT INTO `player_levelupgains` VALUES (2342, 5, 1, 1, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2343, 5, 1, 2, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2344, 5, 1, 3, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2345, 5, 1, 4, 19, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2346, 5, 1, 5, 19, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2347, 5, 1, 6, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2348, 5, 1, 7, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2349, 5, 1, 8, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2350, 5, 1, 9, 19, 0, 1, 0, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2351, 5, 1, 10, 19, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2352, 5, 1, 11, 19, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2353, 5, 1, 12, 19, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2354, 5, 1, 13, 20, 0, 2, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2355, 5, 1, 14, 21, 0, 1, 0, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2356, 5, 1, 15, 22, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2357, 5, 1, 16, 23, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2358, 5, 1, 17, 24, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2359, 5, 1, 18, 25, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2360, 5, 1, 19, 26, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2361, 5, 1, 20, 27, 0, 1, 0, 2, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2362, 5, 1, 21, 28, 0, 1, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2363, 5, 1, 22, 29, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2364, 5, 1, 23, 30, 0, 1, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2365, 5, 1, 24, 31, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2366, 5, 1, 25, 32, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2367, 5, 1, 26, 33, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2368, 5, 1, 27, 34, 0, 1, 1, 1, 1, 0);
INSERT INTO `player_levelupgains` VALUES (2369, 5, 1, 28, 35, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2370, 5, 1, 29, 36, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2371, 5, 1, 30, 37, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2372, 5, 1, 31, 38, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2373, 5, 1, 32, 39, 0, 1, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2374, 5, 1, 33, 40, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2375, 5, 1, 34, 41, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2376, 5, 1, 35, 42, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2377, 5, 1, 36, 44, 0, 1, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2378, 5, 1, 37, 46, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2379, 5, 1, 38, 48, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2380, 5, 1, 39, 50, 0, 2, 1, 1, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2381, 5, 1, 40, 52, 0, 1, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2382, 5, 1, 41, 54, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2383, 5, 1, 42, 56, 0, 2, 1, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2384, 5, 1, 43, 58, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2385, 5, 1, 44, 60, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2386, 5, 1, 45, 62, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2387, 5, 1, 46, 64, 0, 2, 2, 1, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2388, 5, 1, 47, 66, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2389, 5, 1, 48, 68, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2390, 5, 1, 49, 70, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2391, 5, 1, 50, 72, 0, 2, 2, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2392, 5, 1, 51, 74, 0, 2, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2393, 5, 1, 52, 76, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2394, 5, 1, 53, 78, 0, 2, 2, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2395, 5, 1, 54, 80, 0, 3, 1, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2396, 5, 1, 55, 82, 0, 2, 1, 2, 0, 1);
INSERT INTO `player_levelupgains` VALUES (2397, 5, 1, 56, 84, 0, 2, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2398, 5, 1, 57, 86, 0, 2, 1, 2, 1, 1);
INSERT INTO `player_levelupgains` VALUES (2399, 5, 1, 58, 88, 0, 3, 2, 2, 0, 0);
INSERT INTO `player_levelupgains` VALUES (2400, 5, 1, 59, 90, 0, 2, 1, 2, 0, 1);
